/***************************************************************
*** Group Liability Experiment
*** Author: Greg Fischer
*** August 24, 2007
***************************************************************
This file generates the inputs for figures 3 & 4
Figure 3: Risk Taking by Treatment
Figure 4: Mean Transfers by Treatment

*/
***************************************************************
*** SETUP
***************************************************************;
clear							
capture log close				
set memory 100m					
set more off					


/*
*/		
		
		
# delimit;

global resDir "C:\users\greg\documents\docs\research\";
cd "$resDir\groupLiability";

local file = "F3_profitTransFigures";
	local filename =c(pwd)+ "\\`file'.do";
	local logfile  ="logfiles\\`file'.log";
log using `logfile', replace;

***************************************************************
*** Programs
***************************************************************;
cap prog drop fillMat;
program def fillMat;
	args whichMat off row rt;
		if _rc==0 {;
		matrix `whichMat'[`row',`rt'*3+`off']=r(StatTotal);
		};
end;


***************************************************************
*** MAIN DATA
***************************************************************;
use dtafiles\dataFinal, replace;

***************************************************************;
gen reg_depvar 	= "";
gen reg_var 	= "";
gen reg_spec	= "";
gen reg_b		= .;
gen reg_se		= .;

tab session, gen(fe_s);

cap drop reg_*;
gen reg_depvar 	= "";
gen reg_var 	= "";
gen reg_b		= .;
gen reg_se		= .;

local ivar = "r_indiv_0 r_indiv_1 r_jl_0 r_jl_1 r_jla_0 r_jla_1 r_eq_0 r_eq_1";

local i = 1;


reg projProfit `ivar' if markReg==1, cluster(uniqueid);
qui foreach var of local ivar {;
	replace reg_depvar = "`depvar'" if _n==`i';
	replace reg_var = "`var'" if _n==`i';
	replace reg_b   = _b[`var'] if _n==`i';
	replace reg_se   = _se[`var'] if _n==`i';
	local i = `i' + 1;
	};
local i = `i' + 1;

reg trans `ivar' if markReg==1, noc cluster(uniqueid);
qui foreach var of local ivar {;
	replace reg_depvar = "`depvar'" if _n==`i';
	replace reg_var = "`var'" if _n==`i';
	replace reg_b   = _b[`var'] if _n==`i';
	replace reg_se   = _se[`var'] if _n==`i';
	local i = `i' + 1;
	};

		
local i = `i' + 2;
replace reg_depvar = "Source: " + "`filename'" if _n == `i';
	local i = `i' + 1;
replace reg_depvar = "Generated: `c(current_time)' `c(current_date)'" if _n == `i';

local outfile = "excel\F34.out";
outsheet reg_* using `outfile' if _n<=`i', replace;
