***************************************************************
*** Group Liability Experiment
*** Author: Greg Fischer
*** May 11, 2007
*** Revised 14 June 2011
/***************************************************************
This file generates the determinants of transfer behavior table
table 10
*/
***************************************************************
*** SETUP
***************************************************************;
clear	
clear matrix						
capture log close				
set memory 100m					
set more off					


# delimit;

local doroot "$resDir\groupliability\";
cd "`doroot'";

local file = "T10_TransBehavior";
local logfile = "logfiles\\`file'.log";
local filename ="`doroot'do\"+ "`file'.do";

di "filename: `filename'";

log using `logfile', replace;

***************************************************************
*** MAIN DATA
***************************************************************;
use dtafiles\dataFinal, replace;

***************************************************************
*** Session Data
*** Generates Table 10: Transfer Regressions with Kendra Effects
***************************************************************;
local outTable "NewT10_TransBehavior";

gen str `outTable'_row = "";

local startRow = 1;
qui foreach game in 30 40 50 {;
	foreach info in 0 1 {;
		local i = `startRow';
		gen `outTable'_`game'_`info' = .;
		n areg trans payoff p_payoff transNet_Cum if gameEff==`game' & info==`info', absorb(uniqueid) cluster(session);
			replace `outTable'_row = "Own income (B1)" if _n==`i';
				replace `outTable'_`game'_`info' = _b[payoff] if _n==`i'; local ++i;
				replace `outTable'_`game'_`info' = _se[payoff] if _n==`i'; local ++i;
			replace `outTable'_row = "Partners income (B2)" if _n==`i';
				replace `outTable'_`game'_`info' = _b[p_payoff] if _n==`i'; local ++i;
				replace `outTable'_`game'_`info' = _se[p_payoff] if _n==`i'; local ++i;
			replace `outTable'_row = "Cumulative net transfers (d)" if _n==`i';
				replace `outTable'_`game'_`info' = _b[transNet_Cum] if _n==`i'; local ++i;
				replace `outTable'_`game'_`info' = _se[transNet_Cum] if _n==`i';
				local i = `i' + 3;
				
			replace `outTable'_row = "Observations" if _n==`i';
				replace `outTable'_`game'_`info' = e(N) if _n==`i'; local ++i;
			replace `outTable'_row = "R-squared" if _n==`i';
				replace `outTable'_`game'_`info' = e(r2) if _n==`i'; local ++i;
			sum trans if gameEff==`game' & info==`info';
			replace `outTable'_row = "Mean Transfers" if _n==`i';
				replace `outTable'_`game'_`info' = r(mean) if _n==`i';
				local i = `i' + 2;

			};
		};	
local startRow = 1;
qui foreach game in 30 40 50 {;
	foreach info in 0 1 {;
		local i = `startRow';
		gen `outTable'_`game'_`info'_k = .;
		n di "Game: `game'; info: `info'";
		local tnc = "transNet_Cum";
					
		n areg trans payoff p_payoff `tnc' samek if gameEff==`game' & info==`info', absorb(uniqueid) cluster(session);
			replace `outTable'_row = "Own income (B1)" if _n==`i';
				replace `outTable'_`game'_`info'_k = _b[payoff] if _n==`i'; local ++i;
				replace `outTable'_`game'_`info'_k = _se[payoff] if _n==`i'; local ++i;
			replace `outTable'_row = "Partners income (B2)" if _n==`i';
				replace `outTable'_`game'_`info'_k = _b[p_payoff] if _n==`i'; local ++i;
				replace `outTable'_`game'_`info'_k = _se[p_payoff] if _n==`i'; local ++i;
			replace `outTable'_row = "Cumulative net transfers (d)" if _n==`i';
				cap replace `outTable'_`game'_`info'_k = _b[transNet_Cum] if _n==`i'; local ++i;
				cap replace `outTable'_`game'_`info'_k = _se[transNet_Cum] if _n==`i'; local ++i;
			replace `outTable'_row = "Same kendra (k)" if _n==`i';
				replace `outTable'_`game'_`info'_k = _b[samek] if _n==`i'; local ++i;
				replace `outTable'_`game'_`info'_k = _se[samek] if _n==`i';
			
			local i = `i' + 1;
				
			replace `outTable'_row = "Observations" if _n==`i';
				replace `outTable'_`game'_`info'_k = e(N) if _n==`i'; local ++i;
			replace `outTable'_row = "R-squared" if _n==`i';
				replace `outTable'_`game'_`info'_k = e(r2) if _n==`i'; local ++i;
			sum trans if gameEff==`game' & info==`info';
			replace `outTable'_row = "Mean Transfers" if _n==`i';
				replace `outTable'_`game'_`info'_k = r(mean) if _n==`i';
				local i = `i' + 2;
			};
		};	

replace `outTable'_row = "Source: " + "`filename'" if _n == `i';
	local i = `i' + 1;
replace `outTable'_row = "Generated: `c(current_time)' `c(current_date)'" if _n == `i';
	local i = `i' + 1;
						
local outfile = "excel\"+"`outTable'"+".out";
outsheet `outTable'_* using `outfile' if _n<`i', replace;

log close;
