***************************************************************
*** Group Liability Experiment
*** Author: Greg Fischer
*** Based on file from August 24, 2007
*** Revised 22 May 2011
***************************************************************
/*
Table 11: Calculates treatment effect on risk taking
Table 12: Calculates treatment effect on risk taking by risk type
*/		

***************************************************************
*** SETUP
***************************************************************;
clear	
clear matrix						
capture log close				
set memory 100m					
set more off					


# delimit;

local doroot "$resDir\groupliability\";
cd "`doroot'";

local file = "NewT11and12_RiskTaking";
local logfile = "logfiles\\`file'.log";
local filename ="`doroot'do\"+ "`file'.do";

di "filename: `filename'";

log using `logfile', replace;

use dtafiles\dataFinal, replace;

***************************************************************
*** Programs
***************************************************************;
cap prog drop fillt4;
program def fillt4;
	version 9.2;
	* This program fills a row of output table observations with regression results;
	* It works only for the standard table format in paper with;
	* Rows for contract type and columsn for limited information, full info and the difference;
	
	syntax, tableName(string) name(string) whichVar(string) i(real);
		replace `tableName'_Row = "`name'" if _n==`i';
		lincom r_`whichVar'_0 - r_`whichVar'_1;
		
		replace `tableName'_Lim = _b[r_`whichVar'_0] if _n==`i';
		replace `tableName'_Ful = _b[r_`whichVar'_1] if _n==`i';
		replace `tableName'_Dif = r(estimate) if _n==`i';
		
		local i = `i' + 1;
		replace `tableName'_Lim = _se[r_`whichVar'_0] if _n==`i';
		replace `tableName'_Ful = _se[r_`whichVar'_1] if _n==`i';
		replace `tableName'_Dif = r(se) if _n==`i';
	end;
	
cap prog drop fillt4Type;
program def fillt4Type;
	version 9.2;
	* This program fills a row of output table observations with regression results;
	* It works only for the standard table format in paper with;
	* Rows for contract type and columsn for limited information, full info and the difference;
	
	syntax, tableName(string) name(string) whichVar(string) riskType(real) i(real);
		replace `tableName'_Row = "`name'" if _n==`i';
		lincom r_`whichVar'_0 - r_`whichVar'_1;
		
		replace `tableName'_R`riskType'_Lim = _b[r_`whichVar'_0] if _n==`i';
		replace `tableName'_R`riskType'_Ful = _b[r_`whichVar'_1] if _n==`i';
		replace `tableName'_R`riskType'_Dif = r(estimate) if _n==`i';
		
		local i = `i' + 1;
		replace `tableName'_R`riskType'_Lim = _se[r_`whichVar'_0] if _n==`i';
		replace `tableName'_R`riskType'_Ful = _se[r_`whichVar'_1] if _n==`i';
		replace `tableName'_R`riskType'_Dif = r(se) if _n==`i';
	end;
	

cap prog drop fillRel;
program def fillRel;
	version 9.2;
	* This program fills rows of the output table with difference in regression coefficients;
	syntax, tableName(string) treat(string) rel(string) i(real);
		replace `tableName'_Row = "`treat' - `rel'" if _n==`i';
		lincom r_`treat'_0 - r_`rel'_0;
			replace `tableName'_Lim = r(estimate) if _n==`i';
			replace `tableName'_Lim = r(se) if _n==`i'+1;
		
		lincom r_`treat'_1 - r_`rel'_1;
			replace `tableName'_Ful = r(estimate) if _n==`i';
			replace `tableName'_Ful = r(se) if _n==`i'+1;
	end;


***************************************************************
*** MAIN
***************************************************************;
***************************************************************
*** Make Table 11: Effects of Contract Treatments on Risk Taking
***************************************************************;
local tableNameMac "NewT11";
gen str `tableNameMac'_Row="";
gen `tableNameMac'_Lim = .;
gen `tableNameMac'_Ful = .;
gen `tableNameMac'_Dif = .;

reg projProfit r_indiv_0 r_indiv_1 r_jl_0 r_jl_1 r_jla_0 r_jla_1 r_eq_0 r_eq_1 if markReg==1, cluster(session);

fillt4, tableName(`tableNameMac') name(Individual Liability) whichVar(indiv) i(1);
fillt4, tableName(`tableNameMac') name(Joint Liability) whichVar(jl) i(4);
fillt4, tableName(`tableNameMac') name(Joint Liability with Approval) whichVar(jla) i(7);
fillt4, tableName(`tableNameMac') name(Equity) whichVar(eq) i(10);

fillRel, tableName(`tableNameMac') treat(indiv) rel(jl) i(14);
fillRel, tableName(`tableNameMac') treat(jla) rel(jl) i(16);
fillRel, tableName(`tableNameMac') treat(eq) rel(jl) i(18);

fillRel, tableName(`tableNameMac') treat(indiv) rel(jla) i(22);
fillRel, tableName(`tableNameMac') treat(eq) rel(jla) i(24);

replace `tableNameMac'_Row = "Source: " + "`filename'" if _n == 28;
replace `tableNameMac'_Row = "Generated: `c(current_time)' `c(current_date)'" if _n == 29;

local outfile = "excel\\`tableNameMac'.out";
outsheet `tableNameMac'_* using `outfile' if _n<30, replace;

***************************************************************
*** Make Table 12: Effects of Contract Treatments on Risk Taking by Risk Type
***************************************************************;

local tableNameMac "NewT12";
gen str `tableNameMac'_Row="";
foreach stub in R0_Lim R1_Lim R0_Ful R1_Ful R0_Dif R1_Dif {;
	gen `tableNameMac'_`stub' = .;
	};


foreach riskType in 0 1 {;
	reg projProfit r_indiv_0 r_indiv_1 r_jl_0 r_jl_1 r_jla_0 r_jla_1 r_eq_0 r_eq_1 if markReg==1 & risky==`riskType', cluster(session);
	
	replace `tableNameMac'_Row = "Autarky" if _n==1;
		replace `tableNameMac'_R`riskType'_Ful = _b[_cons] if _n==1;
		replace `tableNameMac'_R`riskType'_Ful = _se[_cons] if _n==2;
	
	fillt4Type, tableName(`tableNameMac') name(Individual Liability) whichVar(indiv) riskType(`riskType') i(4);
	fillt4Type, tableName(`tableNameMac') name(Joint Liability) whichVar(jl) riskType(`riskType') i(7);
	fillt4Type, tableName(`tableNameMac') name(Joint Liability with Approval) riskType(`riskType') whichVar(jla) i(10);
	fillt4Type, tableName(`tableNameMac') name(Equity) whichVar(eq) riskType(`riskType') i(13);
};
replace `tableNameMac'_Row = "Source: " + "`filename'" if _n == 17;
replace `tableNameMac'_Row = "Generated: `c(current_time)' `c(current_date)'" if _n == 18;

local outfile = "excel\\`tableNameMac'.out";
outsheet `tableNameMac'_* using `outfile' if _n<30, replace;

log close;
