***************************************************************
*** Group Liability Experiment
*** Author: Greg Fischer
***************************************************************
*** 
*** 23 May 2011
***************************************************************
/*
Calculates risk taking by kendra match types and baseline risk type
*/		

***************************************************************
*** SETUP
***************************************************************;
clear	
clear matrix						
capture log close				
set memory 100m					
set more off					


# delimit;

local doroot "$resDir\groupliability\";
cd "`doroot'";

local file = "T12_KendraEffRiskTaking";
local logfile = "logfiles\\`file'.log";
local filename ="`doroot'do\"+ "`file'.do";

di "filename: `filename'";

log using `logfile', replace;

use dtafiles\datafinal2011, replace;

***************************************************************
*** Programs
***************************************************************;
cap prog drop fillt4;
program def fillt4;
	version 9.2;
	* This program fills a row of output table observations with regression results;
	* It works only for the standard table format in paper with;
	* Rows for contract type and columsn for limited information, full info and the difference;
	
	syntax, tableName(string) name(string) whichVar(string) i(real);
		qui {;
			replace `tableName'_row = "`name'" if _n==`i';
			lincom r_`whichVar'_0 - r_`whichVar'_1;
			
			replace `tableName'_Lim = _b[r_`whichVar'_0] if _n==`i';
			replace `tableName'_Ful = _b[r_`whichVar'_1] if _n==`i';
			replace `tableName'_Dif = r(estimate) if _n==`i';
			
			local i = `i' + 1;
			replace `tableName'_Lim = _se[r_`whichVar'_0] if _n==`i';
			replace `tableName'_Ful = _se[r_`whichVar'_1] if _n==`i';
			replace `tableName'_Dif = r(se) if _n==`i';
		};
	end;

cap prog drop fillRel;
program def fillRel;
	version 9.2;
	* This program fills rows of the output table with difference in regression coefficients;
	syntax, tableName(string) treat(string) rel(string) i(real);
		replace `tableName'_row = "`treat' - `rel'" if _n==`i';
		lincom r_`treat'_0 - r_`rel'_0;
			replace `tableName'_Lim = r(estimate) if _n==`i';
			replace `tableName'_Lim = r(se) if _n==`i'+1;
		
		lincom r_`treat'_1 - r_`rel'_1;
			replace `tableName'_Ful = r(estimate) if _n==`i';
			replace `tableName'_Ful = r(se) if _n==`i'+1;
	end;

cap prog drop fill2cell;
program def fill2cell;
	version 11.0;
	* This program fills rows of an output table with just beta and se estimates;
	syntax, ourVarName(string) treat(string) row(real);
		replace `ourVarName' = _b[r_`treat'] if _n==`row';
		replace `ourVarName' = _se[r_`treat'] if _n==`row'+1;
	end;

cap prog drop fillInfoDiff;
program def fillInfoDiff;
	version 11.0;
	* This program fills rows of an output table with the difference between info treatment variables;
	syntax, outVarName(string) treat1(string) treat0(string) row(real);
		lincom r_`treat0' - r_`treat1';
		replace `outVarName' = r(estimate) if _n==`row';
		replace `outVarName' = r(se) if _n==`row'+1;
	end;
	

***************************************************************
*** MAKE TABLE 12kendra: PANEL A, all risk types
***
*** Redoes the basic table 12 separately for same kendra and different kendra
*** Then runs fully saturated specification and tests for kendra differences
***************************************************************;
local outTable "NewT12_Kendra";
local outTable2 "kCompRisk";
gen str `outTable'_row="";
gen `outTable'_Lim = .;
gen `outTable'_Ful = .;
gen `outTable'_Dif = .;

gen str `outTable2'_row = "";
qui foreach info in 0 1 {;
	qui foreach var in all diffK sameK delta {;
		gen `outTable2'_`var'_`info' = .;
		};
	};
qui foreach var in all diffK sameK delta {;
	gen `outTable2'_`var'_InfoDiff = .;
	};
	

local i = 1;

***************************************************************;
* Full sample regression
***************************************************************;
local startRow = 0;
	replace `outTable2'_row ="All Risk Types: Individual liability" if _n==`startRow'+1;
	replace `outTable2'_row ="All Risk Types: Joint liability" if _n==`startRow'+4;
	replace `outTable2'_row ="All Risk Types: Joint liability w/ approval" if _n==`startRow'+7;
	replace `outTable2'_row ="All Risk Types: Equity/full-insurance" if _n==`startRow'+10;

reg projProfit r_indiv_0 r_indiv_1 r_jl_0 r_jl_1 r_jla_0 r_jla_1 r_eq_0 r_eq_1 if markReg==1, cluster(uniqueid);
est store projProfitAll;
	local whichReg "all";
	local row = `startRow' +1;  fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(indiv_1) row(`row');
	local row = `startRow' +4;  fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(jl_1) row(`row');
	local row = `startRow' +7;  fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(jla_1) row(`row');
	local row = `startRow' +10; fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(eq_1) row(`row');
	local row = `startRow' +1;  fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(indiv_0) row(`row');
	local row = `startRow' +4;  fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(jl_0) row(`row');
	local row = `startRow' +7;  fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(jla_0) row(`row');
	local row = `startRow' +10; fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(eq_0) row(`row');
	local row = `startRow' +1;  fillInfoDiff, outVarName(`outTable2'_`whichReg'_InfoDiff) treat1(indiv_1) treat0(indiv_0) row(`row');
	local row = `startRow' +4;  fillInfoDiff, outVarName(`outTable2'_`whichReg'_InfoDiff) treat1(jl_1) treat0(jl_0) row(`row');
	local row = `startRow' +7;  fillInfoDiff, outVarName(`outTable2'_`whichReg'_InfoDiff) treat1(jla_1) treat0(jla_0) row(`row');
	local row = `startRow' +10; fillInfoDiff, outVarName(`outTable2'_`whichReg'_InfoDiff) treat1(eq_1) treat0(eq_0) row(`row');
	
***************************************************************;
* DIFFERENT KENDRA REGRESSION;
***************************************************************;
reg projProfit r_indiv_0 r_indiv_1 r_jl_0 r_jl_1 r_jla_0 r_jla_1 r_eq_0 r_eq_1 if markReg==1 & (samek==0 | game==20), cluster(uniqueid);
est store projProfitDiff;
	local whichReg "diffK";
	local row = `startRow' +1;  fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(indiv_1) row(`row');
	local row = `startRow' +4;  fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(jl_1) row(`row');
	local row = `startRow' +7;  fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(jla_1) row(`row');
	local row = `startRow' +10; fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(eq_1) row(`row');
	local row = `startRow' +1;  fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(indiv_0) row(`row');
	local row = `startRow' +4;  fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(jl_0) row(`row');
	local row = `startRow' +7;  fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(jla_0) row(`row');
	local row = `startRow' +10; fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(eq_0) row(`row');
	local row = `startRow' +1;  fillInfoDiff, outVarName(`outTable2'_`whichReg'_InfoDiff) treat1(indiv_1) treat0(indiv_0) row(`row');
	local row = `startRow' +4;  fillInfoDiff, outVarName(`outTable2'_`whichReg'_InfoDiff) treat1(jl_1) treat0(jl_0) row(`row');
	local row = `startRow' +7;  fillInfoDiff, outVarName(`outTable2'_`whichReg'_InfoDiff) treat1(jla_1) treat0(jla_0) row(`row');
	local row = `startRow' +10; fillInfoDiff, outVarName(`outTable2'_`whichReg'_InfoDiff) treat1(eq_1) treat0(eq_0) row(`row');

	
	
replace `outTable'_row = "DIFFERENT KENDRA" if _n==`i';local i = `i'+1;
replace `outTable'_row = "All Risk Types: Individual Liability" if _n==`i';
	replace `outTable'_Ful = _b[r_indiv_1] if _n==`i';
	replace `outTable'_Dif = -_b[r_indiv_1] if _n==`i'; local i = `i'+1;
	replace `outTable'_Ful = _se[r_indiv_1] if _n==`i';
	replace `outTable'_Dif = _se[r_indiv_1] if _n==`i'; local i = `i'+2;

fillt4, tableName(`outTable') name(All Risk Types: Joint Liability) whichVar(jl) i(`i'); local i = `i'+3;
fillt4, tableName(`outTable') name(All Risk Types: Joint Liability with Approval) whichVar(jla) i(`i'); local i = `i'+3;
fillt4, tableName(`outTable') name(All Risk Types: Equity) whichVar(eq) i(`i'); local i = `i'+4;

	* This manually calulates the difference between IL and JL with full info;
	lincom r_indiv_1 - r_jl_1;
				replace `outTable'_Ful = r(estimate) if _n==`i'; local i = `i'+1;
				replace `outTable'_Ful = r(se) if _n==`i'; local i = `i'+1;
				
	fillRel, tableName(`outTable') treat(jla) rel(jl) i(`i'); local i = `i'+2;
	fillRel, tableName(`outTable') treat(eq) rel(jl) i(`i'); local i = `i'+4;

	lincom r_indiv_1 - r_jla_1;
				replace `outTable'_Ful = r(estimate) if _n==`i'; local i = `i'+1;
				replace `outTable'_Ful = r(se) if _n==`i'; local i = `i'+1;
	fillRel, tableName(`outTable') treat(eq) rel(jla) i(`i'); local i = `i'+4;

***************************************************************;	
* SAME KENDRA REGRESSION;
***************************************************************;
reg projProfit r_indiv_0 r_indiv_1 r_jl_0 r_jl_1 r_jla_0 r_jla_1 r_eq_0 r_eq_1 if markReg==1 & (samek==1 | game==20), cluster(uniqueid);
est store projProfitSame;
	local whichReg "sameK";
	local row = `startRow' +1;  fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(indiv_1) row(`row');
	local row = `startRow' +4;  fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(jl_1) row(`row');
	local row = `startRow' +7;  fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(jla_1) row(`row');
	local row = `startRow' +10; fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(eq_1) row(`row');
	local row = `startRow' +1;  fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(indiv_0) row(`row');
	local row = `startRow' +4;  fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(jl_0) row(`row');
	local row = `startRow' +7;  fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(jla_0) row(`row');
	local row = `startRow' +10; fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(eq_0) row(`row');
	local row = `startRow' +1;  fillInfoDiff, outVarName(`outTable2'_`whichReg'_InfoDiff) treat1(indiv_1) treat0(indiv_0) row(`row');
	local row = `startRow' +4;  fillInfoDiff, outVarName(`outTable2'_`whichReg'_InfoDiff) treat1(jl_1) treat0(jl_0) row(`row');
	local row = `startRow' +7;  fillInfoDiff, outVarName(`outTable2'_`whichReg'_InfoDiff) treat1(jla_1) treat0(jla_0) row(`row');
	local row = `startRow' +10; fillInfoDiff, outVarName(`outTable2'_`whichReg'_InfoDiff) treat1(eq_1) treat0(eq_0) row(`row');

replace `outTable'_row = "DIFFERENT KENDRA" if _n==`i';local i = `i'+1;
replace `outTable'_row = "Individual Liability" if _n==`i';
	replace `outTable'_Ful = _b[r_indiv_1] if _n==`i';
	replace `outTable'_Dif = -_b[r_indiv_1] if _n==`i'; local i = `i'+1;
	replace `outTable'_Ful = _se[r_indiv_1] if _n==`i';
	replace `outTable'_Dif = _se[r_indiv_1] if _n==`i'; local i = `i'+2;

fillt4, tableName(`outTable') name(Joint Liability) whichVar(jl) i(`i'); local i = `i'+3;
fillt4, tableName(`outTable') name(Joint Liability with Approval) whichVar(jla) i(`i'); local i = `i'+3;
fillt4, tableName(`outTable') name(Equity) whichVar(eq) i(`i'); local i = `i'+4;

	* This manually calulates the difference between IL and JL with full info;
	lincom r_indiv_1 - r_jl_1;
				replace `outTable'_Ful = r(estimate) if _n==`i'; local i = `i'+1;
				replace `outTable'_Ful = r(se) if _n==`i'; local i = `i'+1;
				
	fillRel, tableName(`outTable') treat(jla) rel(jl) i(`i'); local i = `i'+2;
	fillRel, tableName(`outTable') treat(eq) rel(jl) i(`i'); local i = `i'+4;

	lincom r_indiv_1 - r_jla_1;
				replace `outTable'_Ful = r(estimate) if _n==`i'; local i = `i'+1;
				replace `outTable'_Ful = r(se) if _n==`i'; local i = `i'+1;
	fillRel, tableName(`outTable') treat(eq) rel(jla) i(`i'); local i = `i'+4;

***************************************************************;	
* COMBINED REGRESSION;	
***************************************************************;
reg projProfit r_indiv_0 r_indiv_1 r_jl_0 r_jl_1 r_jla_0 r_jla_1 r_eq_0 r_eq_1 r_indiv_0_sk r_indiv_1_sk r_jl_0_sk r_jl_1_sk r_jla_0_sk r_jla_1_sk r_eq_0_sk r_eq_1_sk if markReg==1, cluster(uniqueid);	
est store projProfitInter;
local whichReg "delta";
	local row = `startRow' +1;  fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(indiv_1_sk) row(`row');
	local row = `startRow' +4;  fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(jl_1_sk) row(`row');
	local row = `startRow' +7;  fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(jla_1_sk) row(`row');
	local row = `startRow' +10; fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(eq_1_sk) row(`row');
	local row = `startRow' +1;  fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(indiv_0_sk) row(`row');
	local row = `startRow' +4;  fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(jl_0_sk) row(`row');
	local row = `startRow' +7;  fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(jla_0_sk) row(`row');
	local row = `startRow' +10; fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(eq_0_sk) row(`row');
	local row = `startRow' +1;  fillInfoDiff, outVarName(`outTable2'_`whichReg'_InfoDiff) treat1(indiv_1_sk) treat0(indiv_0_sk) row(`row');
	local row = `startRow' +4;  fillInfoDiff, outVarName(`outTable2'_`whichReg'_InfoDiff) treat1(jl_1_sk) treat0(jl_0_sk) row(`row');
	local row = `startRow' +7;  fillInfoDiff, outVarName(`outTable2'_`whichReg'_InfoDiff) treat1(jla_1_sk) treat0(jla_0_sk) row(`row');
	local row = `startRow' +10; fillInfoDiff, outVarName(`outTable2'_`whichReg'_InfoDiff) treat1(eq_1_sk) treat0(eq_0_sk) row(`row');

***************************************************************
*** MAKE TABLE 12kendra: PANEL B, Low-Risk Types Only
***
*** Redoes the basic table 12 separately for same kendra and different kendra
*** Then runs fully saturated specification and tests for kendra differences
***************************************************************;
local startRow = 13;
	replace `outTable2'_row ="Low Risk Types: Individual liability" if _n==`startRow'+1;
	replace `outTable2'_row ="Low Risk Types: Joint liability" if _n==`startRow'+4;
	replace `outTable2'_row ="Low Risk Types: Joint liability w/ approval" if _n==`startRow'+7;
	replace `outTable2'_row ="Low Risk Types: Equity/full-insurance" if _n==`startRow'+10;

***************************************************************;
* Full sample regression
***************************************************************;
reg projProfit r_indiv_0 r_indiv_1 r_jl_0 r_jl_1 r_jla_0 r_jla_1 r_eq_0 r_eq_1 if markReg==1 & risky==0, cluster(uniqueid);
	local whichReg "all";
	local row = `startRow' +1;  fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(indiv_1) row(`row');
	local row = `startRow' +4;  fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(jl_1) row(`row');
	local row = `startRow' +7;  fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(jla_1) row(`row');
	local row = `startRow' +10; fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(eq_1) row(`row');
	local row = `startRow' +1;  fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(indiv_0) row(`row');
	local row = `startRow' +4;  fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(jl_0) row(`row');
	local row = `startRow' +7;  fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(jla_0) row(`row');
	local row = `startRow' +10; fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(eq_0) row(`row');
	local row = `startRow' +1;  fillInfoDiff, outVarName(`outTable2'_`whichReg'_InfoDiff) treat1(indiv_1) treat0(indiv_0) row(`row');
	local row = `startRow' +4;  fillInfoDiff, outVarName(`outTable2'_`whichReg'_InfoDiff) treat1(jl_1) treat0(jl_0) row(`row');
	local row = `startRow' +7;  fillInfoDiff, outVarName(`outTable2'_`whichReg'_InfoDiff) treat1(jla_1) treat0(jla_0) row(`row');
	local row = `startRow' +10; fillInfoDiff, outVarName(`outTable2'_`whichReg'_InfoDiff) treat1(eq_1) treat0(eq_0) row(`row');

***************************************************************;
* DIFFERENT KENDRA REGRESSION;
***************************************************************;
reg projProfit r_indiv_0 r_indiv_1 r_jl_0 r_jl_1 r_jla_0 r_jla_1 r_eq_0 r_eq_1 if markReg==1 & (samek==0 | game==20) & risky==0, cluster(uniqueid);
	local whichReg "diffK";
	local row = `startRow' +1;  fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(indiv_1) row(`row');
	local row = `startRow' +4;  fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(jl_1) row(`row');
	local row = `startRow' +7;  fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(jla_1) row(`row');
	local row = `startRow' +10; fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(eq_1) row(`row');
	local row = `startRow' +1;  fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(indiv_0) row(`row');
	local row = `startRow' +4;  fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(jl_0) row(`row');
	local row = `startRow' +7;  fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(jla_0) row(`row');
	local row = `startRow' +10; fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(eq_0) row(`row');
	local row = `startRow' +1;  fillInfoDiff, outVarName(`outTable2'_`whichReg'_InfoDiff) treat1(indiv_1) treat0(indiv_0) row(`row');
	local row = `startRow' +4;  fillInfoDiff, outVarName(`outTable2'_`whichReg'_InfoDiff) treat1(jl_1) treat0(jl_0) row(`row');
	local row = `startRow' +7;  fillInfoDiff, outVarName(`outTable2'_`whichReg'_InfoDiff) treat1(jla_1) treat0(jla_0) row(`row');
	local row = `startRow' +10; fillInfoDiff, outVarName(`outTable2'_`whichReg'_InfoDiff) treat1(eq_1) treat0(eq_0) row(`row');

***************************************************************;	
* SAME KENDRA REGRESSION;
***************************************************************;
reg projProfit r_indiv_0 r_indiv_1 r_jl_0 r_jl_1 r_jla_0 r_jla_1 r_eq_0 r_eq_1 if markReg==1 & (samek==1 | game==20) & risky==0, cluster(uniqueid);
	local whichReg "sameK";
	local row = `startRow' +1;  fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(indiv_1) row(`row');
	local row = `startRow' +4;  fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(jl_1) row(`row');
	local row = `startRow' +7;  fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(jla_1) row(`row');
	local row = `startRow' +10; fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(eq_1) row(`row');
	local row = `startRow' +1;  fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(indiv_0) row(`row');
	local row = `startRow' +4;  fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(jl_0) row(`row');
	local row = `startRow' +7;  fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(jla_0) row(`row');
	local row = `startRow' +10; fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(eq_0) row(`row');
	local row = `startRow' +1;  fillInfoDiff, outVarName(`outTable2'_`whichReg'_InfoDiff) treat1(indiv_1) treat0(indiv_0) row(`row');
	local row = `startRow' +4;  fillInfoDiff, outVarName(`outTable2'_`whichReg'_InfoDiff) treat1(jl_1) treat0(jl_0) row(`row');
	local row = `startRow' +7;  fillInfoDiff, outVarName(`outTable2'_`whichReg'_InfoDiff) treat1(jla_1) treat0(jla_0) row(`row');
	local row = `startRow' +10; fillInfoDiff, outVarName(`outTable2'_`whichReg'_InfoDiff) treat1(eq_1) treat0(eq_0) row(`row');

***************************************************************;	
* COMBINED REGRESSION;	
***************************************************************;
reg projProfit r_indiv_0 r_indiv_1 r_jl_0 r_jl_1 r_jla_0 r_jla_1 r_eq_0 r_eq_1 r_indiv_0_sk r_indiv_1_sk r_jl_0_sk r_jl_1_sk r_jla_0_sk r_jla_1_sk r_eq_0_sk r_eq_1_sk if markReg==1 & risky==0, cluster(uniqueid);	
	local whichReg "delta";
	local row = `startRow' +1;  fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(indiv_1_sk) row(`row');
	local row = `startRow' +4;  fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(jl_1_sk) row(`row');
	local row = `startRow' +7;  fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(jla_1_sk) row(`row');
	local row = `startRow' +10; fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(eq_1_sk) row(`row');
	local row = `startRow' +1;  fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(indiv_0_sk) row(`row');
	local row = `startRow' +4;  fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(jl_0_sk) row(`row');
	local row = `startRow' +7;  fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(jla_0_sk) row(`row');
	local row = `startRow' +10; fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(eq_0_sk) row(`row');
	local row = `startRow' +1;  fillInfoDiff, outVarName(`outTable2'_`whichReg'_InfoDiff) treat1(indiv_1_sk) treat0(indiv_0_sk) row(`row');
	local row = `startRow' +4;  fillInfoDiff, outVarName(`outTable2'_`whichReg'_InfoDiff) treat1(jl_1_sk) treat0(jl_0_sk) row(`row');
	local row = `startRow' +7;  fillInfoDiff, outVarName(`outTable2'_`whichReg'_InfoDiff) treat1(jla_1_sk) treat0(jla_0_sk) row(`row');
	local row = `startRow' +10; fillInfoDiff, outVarName(`outTable2'_`whichReg'_InfoDiff) treat1(eq_1_sk) treat0(eq_0_sk) row(`row');

***************************************************************
*** MAKE TABLE 12kendra: PANEL B, High-Risk Types Only
***
*** Redoes the basic table 12 separately for same kendra and different kendra
*** Then runs fully saturated specification and tests for kendra differences
***************************************************************;
local startRow = 26;
	replace `outTable2'_row ="High Risk Types: Individual liability" if _n==`startRow'+1;
	replace `outTable2'_row ="High Risk Types: Joint liability" if _n==`startRow'+4;
	replace `outTable2'_row ="High Risk Types: Joint liability w/ approval" if _n==`startRow'+7;
	replace `outTable2'_row ="High Risk Types: Equity/full-insurance" if _n==`startRow'+10;

***************************************************************;
* Full sample regression
***************************************************************;
reg projProfit r_indiv_0 r_indiv_1 r_jl_0 r_jl_1 r_jla_0 r_jla_1 r_eq_0 r_eq_1 if markReg==1 & risky==1, cluster(uniqueid);
	local whichReg "all";
	local row = `startRow' +1;  fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(indiv_1) row(`row');
	local row = `startRow' +4;  fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(jl_1) row(`row');
	local row = `startRow' +7;  fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(jla_1) row(`row');
	local row = `startRow' +10; fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(eq_1) row(`row');
	local row = `startRow' +1;  fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(indiv_0) row(`row');
	local row = `startRow' +4;  fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(jl_0) row(`row');
	local row = `startRow' +7;  fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(jla_0) row(`row');
	local row = `startRow' +10; fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(eq_0) row(`row');
	local row = `startRow' +1;  fillInfoDiff, outVarName(`outTable2'_`whichReg'_InfoDiff) treat1(indiv_1) treat0(indiv_0) row(`row');
	local row = `startRow' +4;  fillInfoDiff, outVarName(`outTable2'_`whichReg'_InfoDiff) treat1(jl_1) treat0(jl_0) row(`row');
	local row = `startRow' +7;  fillInfoDiff, outVarName(`outTable2'_`whichReg'_InfoDiff) treat1(jla_1) treat0(jla_0) row(`row');
	local row = `startRow' +10; fillInfoDiff, outVarName(`outTable2'_`whichReg'_InfoDiff) treat1(eq_1) treat0(eq_0) row(`row');

***************************************************************;
* DIFFERENT KENDRA REGRESSION;
***************************************************************;
reg projProfit r_indiv_0 r_indiv_1 r_jl_0 r_jl_1 r_jla_0 r_jla_1 r_eq_0 r_eq_1 if markReg==1 & (samek==0 | game==20) & risky==1, cluster(uniqueid);
	local whichReg "diffK";
	local row = `startRow' +1;  fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(indiv_1) row(`row');
	local row = `startRow' +4;  fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(jl_1) row(`row');
	local row = `startRow' +7;  fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(jla_1) row(`row');
	local row = `startRow' +10; fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(eq_1) row(`row');
	local row = `startRow' +1;  fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(indiv_0) row(`row');
	local row = `startRow' +4;  fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(jl_0) row(`row');
	local row = `startRow' +7;  fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(jla_0) row(`row');
	local row = `startRow' +10; fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(eq_0) row(`row');
	local row = `startRow' +1;  fillInfoDiff, outVarName(`outTable2'_`whichReg'_InfoDiff) treat1(indiv_1) treat0(indiv_0) row(`row');
	local row = `startRow' +4;  fillInfoDiff, outVarName(`outTable2'_`whichReg'_InfoDiff) treat1(jl_1) treat0(jl_0) row(`row');
	local row = `startRow' +7;  fillInfoDiff, outVarName(`outTable2'_`whichReg'_InfoDiff) treat1(jla_1) treat0(jla_0) row(`row');
	local row = `startRow' +10; fillInfoDiff, outVarName(`outTable2'_`whichReg'_InfoDiff) treat1(eq_1) treat0(eq_0) row(`row');

***************************************************************;	
* SAME KENDRA REGRESSION;
***************************************************************;
reg projProfit r_indiv_0 r_indiv_1 r_jl_0 r_jl_1 r_jla_0 r_jla_1 r_eq_0 r_eq_1 if markReg==1 & (samek==1 | game==20) & risky==1, cluster(uniqueid);
	local whichReg "sameK";
	local row = `startRow' +1;  fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(indiv_1) row(`row');
	local row = `startRow' +4;  fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(jl_1) row(`row');
	local row = `startRow' +7;  fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(jla_1) row(`row');
	local row = `startRow' +10; fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(eq_1) row(`row');
	local row = `startRow' +1;  fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(indiv_0) row(`row');
	local row = `startRow' +4;  fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(jl_0) row(`row');
	local row = `startRow' +7;  fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(jla_0) row(`row');
	local row = `startRow' +10; fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(eq_0) row(`row');
	local row = `startRow' +1;  fillInfoDiff, outVarName(`outTable2'_`whichReg'_InfoDiff) treat1(indiv_1) treat0(indiv_0) row(`row');
	local row = `startRow' +4;  fillInfoDiff, outVarName(`outTable2'_`whichReg'_InfoDiff) treat1(jl_1) treat0(jl_0) row(`row');
	local row = `startRow' +7;  fillInfoDiff, outVarName(`outTable2'_`whichReg'_InfoDiff) treat1(jla_1) treat0(jla_0) row(`row');
	local row = `startRow' +10; fillInfoDiff, outVarName(`outTable2'_`whichReg'_InfoDiff) treat1(eq_1) treat0(eq_0) row(`row');

***************************************************************;	
* COMBINED REGRESSION;	
***************************************************************;
reg projProfit r_indiv_0 r_indiv_1 r_jl_0 r_jl_1 r_jla_0 r_jla_1 r_eq_0 r_eq_1 r_indiv_0_sk r_indiv_1_sk r_jl_0_sk r_jl_1_sk r_jla_0_sk r_jla_1_sk r_eq_0_sk r_eq_1_sk if markReg==1 & risky==1, cluster(uniqueid);	
	local whichReg "delta";
	local row = `startRow' +1;  fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(indiv_1_sk) row(`row');
	local row = `startRow' +4;  fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(jl_1_sk) row(`row');
	local row = `startRow' +7;  fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(jla_1_sk) row(`row');
	local row = `startRow' +10; fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(eq_1_sk) row(`row');
	local row = `startRow' +1;  fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(indiv_0_sk) row(`row');
	local row = `startRow' +4;  fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(jl_0_sk) row(`row');
	local row = `startRow' +7;  fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(jla_0_sk) row(`row');
	local row = `startRow' +10; fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(eq_0_sk) row(`row');
	local row = `startRow' +1;  fillInfoDiff, outVarName(`outTable2'_`whichReg'_InfoDiff) treat1(indiv_1_sk) treat0(indiv_0_sk) row(`row');
	local row = `startRow' +4;  fillInfoDiff, outVarName(`outTable2'_`whichReg'_InfoDiff) treat1(jl_1_sk) treat0(jl_0_sk) row(`row');
	local row = `startRow' +7;  fillInfoDiff, outVarName(`outTable2'_`whichReg'_InfoDiff) treat1(jla_1_sk) treat0(jla_0_sk) row(`row');
	local row = `startRow' +10; fillInfoDiff, outVarName(`outTable2'_`whichReg'_InfoDiff) treat1(eq_1_sk) treat0(eq_0_sk) row(`row');


***************************************************************;	
* ANNOTATION for panel A AND CLOSING;
***************************************************************;
replace `outTable'_row = "Source: " + "`filename'" if _n == 28; 
replace `outTable'_row = "Generated: `c(current_time)' `c(current_date)'" if _n == 29;

local outfile = "excel\\`outTable'.out";
outsheet `outTable'_* using `outfile' if _n<30, replace;

local startRow = 40;
replace `outTable2'_row = "Standard errors clustered at the individual level" if _n == `startRow';
replace `outTable2'_row = "Source: " + "`filename'" if _n == `startRow'+1; 
replace `outTable2'_row = "Generated: `c(current_time)' `c(current_date)'" if _n == `startRow'+2;

outsheet `outTable2'_* using excel\kendraEffectsProjProfit.out if _n<(`startRow'+3), replace;

log close;
