***************************************************************
*** Group Liability Experiment
*** Author: Greg Fischer
*** Original (as 2means.do) May 11, 2007
*** Revised: 18 May 2011
/***************************************************************
This file produces summary statistics for the key outcomes:
Risk taking, transfers, default rates, and total income
Generates inputs for Table 6
*/
		
***************************************************************
*** SETUP
***************************************************************;
clear	
clear matrix						
capture log close				
set memory 100m					
set more off					


# delimit;

global resDir "C:\Users\fischerg\Documents\Docs\Research";
local doroot "$resDir\groupliability\";
cd "`doroot'";

local file = "T6_SumStats";
local logfile = "logfiles\\`file'.log";
local filename ="`doroot'do\"+ "`file'.do";

di "filename: `filename'";

log using `logfile', replace;

***************************************************************
*** Programs
***************************************************************;
cap prog drop fillMat;
program def fillMat;
	args whichMat off row rt;
		if _rc==0 {;
		matrix `whichMat'[`row',`rt'*3+`off']=r(StatTotal);
		};
end;


***************************************************************
*** MAIN DATA
***************************************************************;
use dtafiles\dataFinal, replace;

local whichTable="NewTable6";
qui foreach var in projProfit trans default totinc {;
	matrix `whichTable'`var' = J(18,7,.);
	local i=0;
	foreach gameRow in 20 30 40 50 70 {;
		matrix `whichTable'`var'[`i'*3+1,1]=`gameRow';
		
		cap tabstat `var' if gameEff==`gameRow' & game==`gameRow' & info==0, stats(mean sd n) save;
			matrix `whichTable'`var'[`i'*3+1,2]=r(StatTotal);
			
		cap tabstat `var' if gameEff==`gameRow'  & game==`gameRow' & info==1, stats(mean sd n) save;
			matrix `whichTable'`var'[`i'*3+1,3]=r(StatTotal);	
			
		tabstat `var' if gameEff==`gameRow' & game==`gameRow', stats(mean sd n) save;
			matrix `whichTable'`var'[`i'*3+1,5]=r(StatTotal);	
		
		cap ttest `var' if gameEff==`gameRow'  & game==`gameRow', by(info);
			matrix `whichTable'`var'[`i'*3+1,7]=r(mu_2)-r(mu_1);
			matrix `whichTable'`var'[`i'*3+2,7]=r(p);
		
		preserve;
		drop _all;
		svmat `whichTable'`var';
		local outfile = "excel\"+"`whichTable'"+"`var'.out";
		di "`outfile'";
		
		set obs 23;
		gen note = "";
		order note;
		
		replace note = "Source: " + "`filename'" if _n == 20;
		replace note = "Generated: `c(current_time)' `c(current_date)'" if _n == 21;

		outsheet using `outfile', replace;
		restore;
				
		local i=`i'+1;	
		
		};
	};		
log close;
