***************************************************************
*** Group Liability Experiment
*** Author: Greg Fischer
*** August 24, 2007
*** Revised 14 June 2011
*** Revised 21 July 2011
***************************************************************
/*
Calculates realized NET transfers as percentage of full risk sharing
Then does this only in cases where only one project succeeds
These are summary statistics, not regression tables
Split by all, same and different kendra
THIS FILE MAKES THE OUTPUT FOR BOTH TABLE 7 AND TABLE 7A (ONLINE APPENDIX)
*/		

***************************************************************
*** SETUP
***************************************************************;
clear	
clear matrix						
capture log close				
set memory 100m					
set more off					


# delimit;

local doroot "$resDir\groupliability\";
cd "`doroot'";

local file = "T7_Transfers";
local logfile = "logfiles\\`file'.log";
local filename ="`doroot'do\"+ "`file'.do";

di "filename: `filename'";

log using `logfile', replace;

use dtafiles\dataFinal, replace;

* Matlab directories;
* LSE desktop;
	*local matlabDir "C:\Users\fischerg\Documents\Docs\Research\groupLiability\MATLAB";
* Tablet;
	local matlabDir "C:\Users\Greg\Documents\Docs\Research\groupLiability\MATLAB2012";
* Home;
	*local matlabDir "C:\Users\GREG\Documents\Docs\Research\groupLiability\MATLAB\"

***************************************************************
*** MERGE CPO Transfer calculations
***************************************************************;

preserve;
*** Generate IL-HH transfer matrix;
drop _all;
insheet using "`matlabDir'\CPOTransHH-IL6.csv";
mkmat v1-v64, matrix(transIL_11);

*** Generate IL-HL transfer matrix;
drop _all;
insheet using "`matlabDir'\CPOTransHL-IL6.csv";
mkmat v1-v64, matrix(transIL_10);

*** Generate IL-LH transfer matrix;
drop _all;
insheet using "`matlabDir'\CPOTransLH-IL6.csv";
mkmat v1-v64, matrix(transIL_01);

*** Generate IL-LL transfer matrix;
drop _all;
insheet using "`matlabDir'\CPOTransLL-IL6.csv";
mkmat v1-v64, matrix(transIL_00);

*** Generate JL-HH transfer matrix;
drop _all;
insheet using "`matlabDir'\CPOTransHH_JL6.csv";
mkmat v65-v128, matrix(transJL_11);

*** Generate JL-HL transfer matrix;
drop _all;
insheet using "`matlabDir'\CPOTransHL_JL6.csv";
mkmat v65-v128, matrix(transJL_10);

*** Generate JL-LH transfer matrix;
drop _all;
insheet using "`matlabDir'\CPOTransLH_JL6.csv";
mkmat v65-v128, matrix(transJL_01);

*** Generate JL-LL transfer matrix;
drop _all;
insheet using "`matlabDir'\CPOTransLL_JL6.csv";
mkmat v65-v128, matrix(transJL_00);

restore;

gen maxTransIL = .;  // Generate placeholders for numerically calculated constrained efficient transfers;
gen maxTransJL = .;

***************************************************************
* This section inputs numerically calcuated MATLAB estimates of constrained effecient transfers	
***************************************************************;
local nobs = _N;	
qui forvalues i = 1/`nobs' {;
	if riskBmark[`i']<. & p_riskBmark[`i']<. & proj[`i']<. & p_proj[`i']<. & stone[`i']<. & p_stone[`i']<. {;
		di "Iter: `i'";
		local bm = riskBmark[`i'];
		local bm2 = p_riskBmark[`i'];
		local p1 = proj[`i'];
		local p2 = p_proj[`i'];
		local out1 = stone[`i'];
		local out2 = p_stone[`i'];
		local colAlt = (`bm'-1)*8+`p1';
		local rowAlt = (`bm2'-1)*8+`p2';
		replace maxTransIL = transIL_`out1'`out2'[`colAlt',`rowAlt'] if _n==`i';
		replace maxTransJL = transJL_`out1'`out2'[`colAlt',`rowAlt'] if _n==`i';
		};
	};	
		
gen transIL = max(maxTransIL,0);
gen transJL = max(maxTransJL,0);

gen transCPO = transIL if gameEff==30;
	replace transCPO = transJL if gameEff==40 | gameEff==50;

gen transCPONeg = maxTransIL if gameEff==30;
	replace transCPONeg = maxTransJL if gameEff==40 | gameEff==50;	

local inclusionVar "inclhi";  

***************************************************************
*** Make Table 7: Summary of Transfers
***************************************************************;
local outTable "T7";
gen str `outTable'_Game="";
local i=1;
qui foreach kend in all sameK diffK {;
	qui foreach var in transAll transOneWin transBothWin transNoWin {;
		gen `outTable'_`kend'_`var'_0 = .;
		gen `outTable'_`kend'_`var'_1 = .;
		gen `outTable'_`kend'_sp`i' = .;
		local ++i;
		};
};

qui foreach kend in all sameK diffK {;
	if "`kend'" == "all" {;
			local kqual = "";
			};
		else if "`kend'" == "sameK" {;
			local kqual = "& samek==1";
			};
		else if "`kend'" == "diffK" {;
			local kqual = "& samek!=1";
			};	
		foreach info in 0 1 {;
			local i = 1;
			foreach g in 30 40 50 {;
				replace `outTable'_Game = "`g': `kend'" if _n==`i';
				sum transNet if gameEff==`g' & info==`info' & `inclusionVar'==1 `kqual';
					replace `outTable'_`kend'_transAll_`info'=r(mean) if _n==`i';
					scalar tN_Tot = r(mean);
				sum transNet if gameEff==`g' & info==`info' & `inclusionVar'==1 & ((stone+p_stone)==1) `kqual';
					replace `outTable'_`kend'_transOneWin_`info'=r(mean) if _n==`i';
					scalar tN_oneWin = r(mean);
				sum transNet if gameEff==`g' & info==`info' & `inclusionVar'==1 & (((stone+p_stone)==2) | ((stone+p_stone)==0))`kqual';
					replace `outTable'_`kend'_transBothWin_`info'=r(mean) if _n==`i';
					scalar tN_bothWin = r(mean);
				sum transNet if gameEff==`g' & info==`info' & `inclusionVar'==1 & ((stone+p_stone)==0) `kqual';
					replace `outTable'_`kend'_transNoWin_`info'=r(mean) if _n==`i';
					scalar tN_noWin = r(mean);
			
					
				local i = `i' + 1;
				sum transFull if gameEff==`g' & info==`info' & `inclusionVar'==1 `kqual';
					replace `outTable'_`kend'_transAll_`info'=r(mean) if _n==`i';
					scalar tF_Tot = r(mean);
				sum transFull if gameEff==`g' & info==`info' & `inclusionVar'==1 & ((stone+p_stone)==1) `kqual';
					replace `outTable'_`kend'_transOneWin_`info'=r(mean) if _n==`i';
					scalar tF_oneWin = r(mean);	
				sum transFull if gameEff==`g' & info==`info' & `inclusionVar'==1 & (((stone+p_stone)==2) | ((stone+p_stone)==0)) `kqual';
					replace `outTable'_`kend'_transBothWin_`info'=r(mean) if _n==`i';
					scalar tF_bothWin = r(mean);	
				sum transFull if gameEff==`g' & info==`info' & `inclusionVar'==1 & ((stone+p_stone)==0) `kqual';
					replace `outTable'_`kend'_transNoWin_`info'=r(mean) if _n==`i';
					scalar tF_noWin = r(mean);
					
				local i = `i' + 1;
				replace `outTable'_`kend'_transAll_`info'= tN_Tot/tF_Tot if _n==`i';
				replace `outTable'_`kend'_transOneWin_`info'= tN_oneWin/tF_oneWin if _n==`i';
				replace `outTable'_`kend'_transBothWin_`info'= tN_bothWin/tF_bothWin if _n==`i';
				replace `outTable'_`kend'_transNoWin_`info'= tN_noWin/tF_noWin if _n==`i';	
					
				local i = `i' + 1;
				sum transCPO if gameEff==`g' & info==`info' & `inclusionVar'==1 `kqual';
					replace `outTable'_`kend'_transAll_`info'=r(mean) if _n==`i';
					scalar tC_Tot = r(mean);
				sum transCPO if gameEff==`g' & info==`info' & `inclusionVar'==1 & ((stone+p_stone)==1) `kqual';
					replace `outTable'_`kend'_transOneWin_`info'=r(mean) if _n==`i';
					scalar tC_oneWin = r(mean);	
				sum transCPO if gameEff==`g' & info==`info' & `inclusionVar'==1 & (((stone+p_stone)==2) | ((stone+p_stone)==0)) `kqual';
					replace `outTable'_`kend'_transBothWin_`info'=r(mean) if _n==`i';
					scalar tC_bothWin = r(mean);	
				sum transCPO if gameEff==`g' & info==`info' & `inclusionVar'==1 & ((stone+p_stone)==0) `kqual';
					replace `outTable'_`kend'_transNoWin_`info'=r(mean) if _n==`i';
					scalar tC_noWin = r(mean);		
					
				local i = `i' + 1;
				replace `outTable'_`kend'_transAll_`info'= tN_Tot/tC_Tot if _n==`i';
				replace `outTable'_`kend'_transOneWin_`info'= tN_oneWin/tC_oneWin if _n==`i';
				replace `outTable'_`kend'_transBothWin_`info'= tN_bothWin/tC_bothWin if _n==`i';
				replace `outTable'_`kend'_transNoWin_`info'= tN_noWin/tC_noWin if _n==`i';	
				
				local i = `i' + 2;
			};
		};
};

local i = `i' + 3;
replace `outTable'_Game = "Source: " + "`filename'" if _n == `i'; local ++i;
replace `outTable'_Game = "Generated: `c(current_time)' `c(current_date)'" if _n == `i'; local ++i;

local outfile = "excel\\`outTable'.out";
outsheet `outTable'_* using `outfile' if _n<`i', replace;

