***************************************************************
*** Group Liability Experiment
*** Author: Greg Fischer
*** August 24, 2007
***************************************************************
*** 
*** Revised 17 May 2011
***************************************************************
/*
*/		

***************************************************************
*** SETUP
***************************************************************;
clear	
clear matrix						
capture log close				
set memory 100m					
set more off					


# delimit;

local doroot "$resDir\groupliability\";
cd "`doroot'";

local file = "T8_KendraEffects";
local logfile = "logfiles\\`file'.log";
local filename ="`doroot'do\"+ "`file'.do";

di "filename: `filename'";

log using `logfile', replace;

use dtafiles\dataFinal, replace;

***************************************************************
*** Programs
***************************************************************;
cap prog drop fillt4;
program def fillt4;
	version 9.2;
	* This program fills a row of output table observations with regression results;
	* It works only for the standard table format in paper with;
	* Rows for contract type and columsn for limited information, full info and the difference;
	
	syntax, tableName(string) name(string) whichVar(string) i(real);
		replace `tableName'_row = "`name'" if _n==`i';
		lincom r_`whichVar'_0 - r_`whichVar'_1;
		
		replace `tableName'_Lim = _b[r_`whichVar'_0] if _n==`i';
		replace `tableName'_Ful = _b[r_`whichVar'_1] if _n==`i';
		replace `tableName'_Dif = r(estimate) if _n==`i';
		
		local i = `i' + 1;
		replace `tableName'_Lim = _se[r_`whichVar'_0] if _n==`i';
		replace `tableName'_Ful = _se[r_`whichVar'_1] if _n==`i';
		replace `tableName'_Dif = r(se) if _n==`i';
	end;

cap prog drop fillRel;
program def fillRel;
	version 9.2;
	* This program fills rows of the output table with difference in regression coefficients;
	syntax, tableName(string) treat(string) rel(string) i(real);
		replace `tableName'_row = "`treat' - `rel'" if _n==`i';
		lincom r_`treat'_0 - r_`rel'_0;
			replace `tableName'_Lim = r(estimate) if _n==`i';
			replace `tableName'_Lim = r(se) if _n==`i'+1;
		
		lincom r_`treat'_1 - r_`rel'_1;
			replace `tableName'_Ful = r(estimate) if _n==`i';
			replace `tableName'_Ful = r(se) if _n==`i'+1;
	end;

cap prog drop fill2cell;
program def fill2cell;
	version 11.0;
	* This program fills rows of an output table with just beta and se estimates;
	syntax, ourVarName(string) treat(string) row(real);
		replace `ourVarName' = _b[r_`treat'] if _n==`row';
		replace `ourVarName' = _se[r_`treat'] if _n==`row'+1;
	end;
	
cap prog drop fillInfoDiff;
program def fillInfoDiff;
	version 11.0;
	* This program fills rows of an output table with the difference between info treatment variables;
	syntax, outVarName(string) treat1(string) treat0(string) row(real);
		lincom r_`treat0' - r_`treat1';
		replace `outVarName' = r(estimate) if _n==`row';
		replace `outVarName' = r(se) if _n==`row'+1;
	end;

	
***************************************************************
***************************************************************
*** MAKE TABLE 8: PANEL A
***
*** Redoes the basic table 8 separately for same kendra and different kendra
*** Then runs fully saturated specification and tests for kendra differences
***************************************************************;
local outTable "NewT8_Kendra";
local outTable2 "kCompTrans";
gen str `outTable'_row="";
gen `outTable'_Lim = .;
gen `outTable'_Ful = .;
gen `outTable'_Dif = .;

gen str `outTable2'_row = "";
qui foreach info in 0 1 {;
	qui foreach var in all diffK sameK delta {;
		gen `outTable2'_`var'_`info' = .;
		};
	};
qui foreach var in all diffK sameK delta {;
	gen `outTable2'_`var'_InfoDiff = .;
	};
	

local i = 1;
replace `outTable2'_row ="Individual liability" if _n==1;
replace `outTable2'_row ="Joint liability" if _n==4;
replace `outTable2'_row ="Joint liability w/ approval" if _n==7;
replace `outTable2'_row ="Equity/full-insurance" if _n==10;

***************************************************************;
* Full sample regression
***************************************************************;
reg trans r_indiv_0 r_indiv_1 r_jl_0 r_jl_1 r_jla_0 r_jla_1 r_eq_0 r_eq_1 if markRegTran==1, cluster(uniqueid) noc;
est store transAll;
local whichReg "all";
fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(indiv_1) row(1);
fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(jl_1) row(4);
fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(jla_1) row(7);
fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(eq_1) row(10);
fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(indiv_0) row(1);
fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(jl_0) row(4);
fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(jla_0) row(7);
fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(eq_0) row(10);
fillInfoDiff, outVarName(`outTable2'_all_InfoDiff) treat1(indiv_1) treat0(indiv_0) row(1);
fillInfoDiff, outVarName(`outTable2'_all_InfoDiff) treat1(jl_1) treat0(jl_0) row(4);
fillInfoDiff, outVarName(`outTable2'_all_InfoDiff) treat1(jla_1) treat0(jla_0) row(7);
fillInfoDiff, outVarName(`outTable2'_all_InfoDiff) treat1(eq_1) treat0(eq_0) row(10);

***************************************************************;
* DIFFERENT KENDRA REGRESSION;
***************************************************************;
reg trans r_indiv_0 r_indiv_1 r_jl_0 r_jl_1 r_jla_0 r_jla_1 r_eq_0 r_eq_1 if markRegTran==1 & samek==0, cluster(uniqueid) noc;
est store transDiff;
local whichReg "diffK";
fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(indiv_1) row(1);
fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(jl_1) row(4);
fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(jla_1) row(7);
fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(eq_1) row(10);
fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(indiv_0) row(1);
fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(jl_0) row(4);
fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(jla_0) row(7);
fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(eq_0) row(10);
fillInfoDiff, outVarName(`outTable2'_diffK_InfoDiff) treat1(indiv_1) treat0(indiv_0) row(1);
fillInfoDiff, outVarName(`outTable2'_diffK_InfoDiff) treat1(jl_1) treat0(jl_0) row(4);
fillInfoDiff, outVarName(`outTable2'_diffK_InfoDiff) treat1(jla_1) treat0(jla_0) row(7);
fillInfoDiff, outVarName(`outTable2'_diffK_InfoDiff) treat1(eq_1) treat0(eq_0) row(10);


replace `outTable'_row = "DIFFERENT KENDRA" if _n==`i';local i = `i'+1;
replace `outTable'_row = "Individual Liability" if _n==`i';
	replace `outTable'_Ful = _b[r_indiv_1] if _n==`i';
	replace `outTable'_Dif = -_b[r_indiv_1] if _n==`i'; local i = `i'+1;
	replace `outTable'_Ful = _se[r_indiv_1] if _n==`i';
	replace `outTable'_Dif = _se[r_indiv_1] if _n==`i'; local i = `i'+2;

fillt4, tableName(`outTable') name(Joint Liability) whichVar(jl) i(`i'); local i = `i'+3;
fillt4, tableName(`outTable') name(Joint Liability with Approval) whichVar(jla) i(`i'); local i = `i'+3;
fillt4, tableName(`outTable') name(Equity) whichVar(eq) i(`i'); local i = `i'+4;

	* This manually calulates the difference between IL and JL with full info;
	lincom r_indiv_1 - r_jl_1;
				replace `outTable'_Ful = r(estimate) if _n==`i'; local i = `i'+1;
				replace `outTable'_Ful = r(se) if _n==`i'; local i = `i'+1;
				
	fillRel, tableName(`outTable') treat(jla) rel(jl) i(`i'); local i = `i'+2;
	fillRel, tableName(`outTable') treat(eq) rel(jl) i(`i'); local i = `i'+4;

	lincom r_indiv_1 - r_jla_1;
				replace `outTable'_Ful = r(estimate) if _n==`i'; local i = `i'+1;
				replace `outTable'_Ful = r(se) if _n==`i'; local i = `i'+1;
	fillRel, tableName(`outTable') treat(eq) rel(jla) i(`i'); local i = `i'+4;

***************************************************************;	
* SAME KENDRA REGRESSION;
***************************************************************;
reg trans r_indiv_0 r_indiv_1 r_jl_0 r_jl_1 r_jla_0 r_jla_1 r_eq_0 r_eq_1 if markRegTran==1 & samek==1, cluster(uniqueid) noc;
est store transSame;
local whichReg "sameK";
fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(indiv_1) row(1);
fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(jl_1) row(4);
fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(jla_1) row(7);
fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(eq_1) row(10);
fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(indiv_0) row(1);
fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(jl_0) row(4);
fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(jla_0) row(7);
fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(eq_0) row(10);
fillInfoDiff, outVarName(`outTable2'_sameK_InfoDiff) treat1(indiv_1) treat0(indiv_0) row(1);
fillInfoDiff, outVarName(`outTable2'_sameK_InfoDiff) treat1(jl_1) treat0(jl_0) row(4);
fillInfoDiff, outVarName(`outTable2'_sameK_InfoDiff) treat1(jla_1) treat0(jla_0) row(7);
fillInfoDiff, outVarName(`outTable2'_sameK_InfoDiff) treat1(eq_1) treat0(eq_0) row(10);


replace `outTable'_row = "DIFFERENT KENDRA" if _n==`i';local i = `i'+1;
replace `outTable'_row = "Individual Liability" if _n==`i';
	replace `outTable'_Ful = _b[r_indiv_1] if _n==`i';
	replace `outTable'_Dif = -_b[r_indiv_1] if _n==`i'; local i = `i'+1;
	replace `outTable'_Ful = _se[r_indiv_1] if _n==`i';
	replace `outTable'_Dif = _se[r_indiv_1] if _n==`i'; local i = `i'+2;

fillt4, tableName(`outTable') name(Joint Liability) whichVar(jl) i(`i'); local i = `i'+3;
fillt4, tableName(`outTable') name(Joint Liability with Approval) whichVar(jla) i(`i'); local i = `i'+3;
fillt4, tableName(`outTable') name(Equity) whichVar(eq) i(`i'); local i = `i'+4;

	* This manually calulates the difference between IL and JL with full info;
	lincom r_indiv_1 - r_jl_1;
				replace `outTable'_Ful = r(estimate) if _n==`i'; local i = `i'+1;
				replace `outTable'_Ful = r(se) if _n==`i'; local i = `i'+1;
				
	fillRel, tableName(`outTable') treat(jla) rel(jl) i(`i'); local i = `i'+2;
	fillRel, tableName(`outTable') treat(eq) rel(jl) i(`i'); local i = `i'+4;

	lincom r_indiv_1 - r_jla_1;
				replace `outTable'_Ful = r(estimate) if _n==`i'; local i = `i'+1;
				replace `outTable'_Ful = r(se) if _n==`i'; local i = `i'+1;
	fillRel, tableName(`outTable') treat(eq) rel(jla) i(`i'); local i = `i'+4;

***************************************************************;	
* COMBINED REGRESSION;	
***************************************************************;
reg trans r_indiv_0 r_indiv_1 r_jl_0 r_jl_1 r_jla_0 r_jla_1 r_eq_0 r_eq_1 r_indiv_0_sk r_indiv_1_sk r_jl_0_sk r_jl_1_sk r_jla_0_sk r_jla_1_sk r_eq_0_sk r_eq_1_sk if markRegTran==1, cluster(uniqueid) noc;	
est store transInter;
local whichReg "delta";
fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(indiv_1_sk) row(1);
fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(jl_1_sk) row(4);
fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(jla_1_sk) row(7);
fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(eq_1_sk) row(10);
fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(indiv_0_sk) row(1);
fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(jl_0_sk) row(4);
fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(jla_0_sk) row(7);
fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(eq_0_sk) row(10);
fillInfoDiff, outVarName(`outTable2'_delta_InfoDiff) treat1(indiv_1_sk) treat0(indiv_0_sk) row(1);
fillInfoDiff, outVarName(`outTable2'_delta_InfoDiff) treat1(jl_1_sk) treat0(jl_0_sk) row(4);
fillInfoDiff, outVarName(`outTable2'_delta_InfoDiff) treat1(jla_1_sk) treat0(jla_0_sk) row(7);
fillInfoDiff, outVarName(`outTable2'_delta_InfoDiff) treat1(eq_1_sk) treat0(eq_0_sk) row(10);

***************************************************************;	
* ANNOTATION for panel A AND CLOSING;
***************************************************************;
replace `outTable'_row = "Source: " + "`filename'" if _n == 28; 
replace `outTable'_row = "Generated: `c(current_time)' `c(current_date)'" if _n == 29;

local outfile = "excel\\`outTable'.out";
outsheet `outTable'_* using `outfile' if _n<30, replace;

replace `outTable2'_row = "Standard errors clustered at the individual level" if _n == 14;
replace `outTable2'_row = "Source: " + "`filename'" if _n == 15; 
replace `outTable2'_row = "Generated: `c(current_time)' `c(current_date)'" if _n == 16;

outsheet `outTable2'_* using excel\kendraEffectsTrans.out if _n<17, replace;


***************************************************************
***************************************************************
*** MAKE TABLE 8, PANEL B
***
*** Redoes the basic table 9 (Upside transfers) separately for same kendra and different kendra
*** Then runs fully saturated specification and tests for kendra differences
***************************************************************;
local outTable "NewT9_Kendra";
local outTable2 "kCompTransUp";
gen str `outTable'_row="";
gen `outTable'_Lim = .;
gen `outTable'_Ful = .;
gen `outTable'_Dif = .;

gen str `outTable2'_row = "";
qui foreach info in 0 1 {;
	qui foreach var in all diffK sameK delta {;
		gen `outTable2'_`var'_`info' = .;
		};
	};
qui foreach var in all diffK sameK delta {;
	gen `outTable2'_`var'_InfoDiff = .;
	};
	

local i = 1;
replace `outTable2'_row ="Individual liability" if _n==1;
replace `outTable2'_row ="Joint liability" if _n==4;
replace `outTable2'_row ="Joint liability w/ approval" if _n==7;
replace `outTable2'_row ="Equity/full-insurance: NOT USED" if _n==10;

***************************************************************;
* Full sample regression
***************************************************************;
reg transUp r_indiv_0 r_indiv_1 r_jl_0 r_jl_1 r_jla_0 r_jla_1 if markRegTran==1 & gameEff~=70 & stone==1, cluster(uniqueid) noc;
est store transAll;
local whichReg "all";
fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(indiv_1) row(1);
fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(jl_1) row(4);
fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(jla_1) row(7);
fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(indiv_0) row(1);
fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(jl_0) row(4);
fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(jla_0) row(7);
fillInfoDiff, outVarName(`outTable2'_all_InfoDiff) treat1(indiv_1) treat0(indiv_0) row(1);
fillInfoDiff, outVarName(`outTable2'_all_InfoDiff) treat1(jl_1) treat0(jl_0) row(4);
fillInfoDiff, outVarName(`outTable2'_all_InfoDiff) treat1(jla_1) treat0(jla_0) row(7);


***************************************************************;
* DIFFERENT KENDRA REGRESSION;
***************************************************************;
reg trans r_indiv_0 r_indiv_1 r_jl_0 r_jl_1 r_jla_0 r_jla_1 if markRegTran==1 & samek==0 & gameEff~=70 & stone==1, cluster(uniqueid) noc;
est store transDiff;
local whichReg "diffK";
fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(indiv_1) row(1);
fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(jl_1) row(4);
fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(jla_1) row(7);
fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(indiv_0) row(1);
fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(jl_0) row(4);
fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(jla_0) row(7);
fillInfoDiff, outVarName(`outTable2'_diffK_InfoDiff) treat1(indiv_1) treat0(indiv_0) row(1);
fillInfoDiff, outVarName(`outTable2'_diffK_InfoDiff) treat1(jl_1) treat0(jl_0) row(4);
fillInfoDiff, outVarName(`outTable2'_diffK_InfoDiff) treat1(jla_1) treat0(jla_0) row(7);

replace `outTable'_row = "DIFFERENT KENDRA" if _n==`i';local i = `i'+1;
replace `outTable'_row = "Individual Liability" if _n==`i';
	replace `outTable'_Ful = _b[r_indiv_1] if _n==`i';
	replace `outTable'_Dif = -_b[r_indiv_1] if _n==`i'; local i = `i'+1;
	replace `outTable'_Ful = _se[r_indiv_1] if _n==`i';
	replace `outTable'_Dif = _se[r_indiv_1] if _n==`i'; local i = `i'+2;

fillt4, tableName(`outTable') name(Joint Liability) whichVar(jl) i(`i'); local i = `i'+3;
fillt4, tableName(`outTable') name(Joint Liability with Approval) whichVar(jla) i(`i'); local i = `i'+3;

	* This manually calulates the difference between IL and JL with full info;
	lincom r_indiv_1 - r_jl_1;
				replace `outTable'_Ful = r(estimate) if _n==`i'; local i = `i'+1;
				replace `outTable'_Ful = r(se) if _n==`i'; local i = `i'+1;
				
	fillRel, tableName(`outTable') treat(jla) rel(jl) i(`i'); local i = `i'+2;
	
	lincom r_indiv_1 - r_jla_1;
				replace `outTable'_Ful = r(estimate) if _n==`i'; local i = `i'+1;
				replace `outTable'_Ful = r(se) if _n==`i'; local i = `i'+1;
	
***************************************************************;	
* SAME KENDRA REGRESSION;
***************************************************************;
reg trans r_indiv_0 r_indiv_1 r_jl_0 r_jl_1 r_jla_0 r_jla_1 if markRegTran==1 & samek==1 & gameEff~=70 & stone==1, cluster(uniqueid) noc;
est store transSame;
local whichReg "sameK";
fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(indiv_1) row(1);
fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(jl_1) row(4);
fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(jla_1) row(7);
fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(indiv_0) row(1);
fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(jl_0) row(4);
fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(jla_0) row(7);
fillInfoDiff, outVarName(`outTable2'_sameK_InfoDiff) treat1(indiv_1) treat0(indiv_0) row(1);
fillInfoDiff, outVarName(`outTable2'_sameK_InfoDiff) treat1(jl_1) treat0(jl_0) row(4);
fillInfoDiff, outVarName(`outTable2'_sameK_InfoDiff) treat1(jla_1) treat0(jla_0) row(7);

replace `outTable'_row = "DIFFERENT KENDRA" if _n==`i';local i = `i'+1;
replace `outTable'_row = "Individual Liability" if _n==`i';
	replace `outTable'_Ful = _b[r_indiv_1] if _n==`i';
	replace `outTable'_Dif = -_b[r_indiv_1] if _n==`i'; local i = `i'+1;
	replace `outTable'_Ful = _se[r_indiv_1] if _n==`i';
	replace `outTable'_Dif = _se[r_indiv_1] if _n==`i'; local i = `i'+2;

fillt4, tableName(`outTable') name(Joint Liability) whichVar(jl) i(`i'); local i = `i'+3;
fillt4, tableName(`outTable') name(Joint Liability with Approval) whichVar(jla) i(`i'); local i = `i'+3;

	* This manually calulates the difference between IL and JL with full info;
	lincom r_indiv_1 - r_jl_1;
				replace `outTable'_Ful = r(estimate) if _n==`i'; local i = `i'+1;
				replace `outTable'_Ful = r(se) if _n==`i'; local i = `i'+1;
				
	fillRel, tableName(`outTable') treat(jla) rel(jl) i(`i'); local i = `i'+2;

	lincom r_indiv_1 - r_jla_1;
				replace `outTable'_Ful = r(estimate) if _n==`i'; local i = `i'+1;
				replace `outTable'_Ful = r(se) if _n==`i'; local i = `i'+1;

***************************************************************;	
* COMBINED REGRESSION;	
***************************************************************;
reg trans r_indiv_0 r_indiv_1 r_jl_0 r_jl_1 r_jla_0 r_jla_1 r_indiv_0_sk r_indiv_1_sk r_jl_0_sk r_jl_1_sk r_jla_0_sk r_jla_1_sk if markRegTran==1 & gameEff~=70 & stone==1, cluster(uniqueid) noc;	
est store transInter;
local whichReg "delta";
fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(indiv_1_sk) row(1);
fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(jl_1_sk) row(4);
fill2cell, ourVarName(`outTable2'_`whichReg'_1) treat(jla_1_sk) row(7);
fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(indiv_0_sk) row(1);
fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(jl_0_sk) row(4);
fill2cell, ourVarName(`outTable2'_`whichReg'_0) treat(jla_0_sk) row(7);
fillInfoDiff, outVarName(`outTable2'_delta_InfoDiff) treat1(indiv_1_sk) treat0(indiv_0_sk) row(1);
fillInfoDiff, outVarName(`outTable2'_delta_InfoDiff) treat1(jl_1_sk) treat0(jl_0_sk) row(4);
fillInfoDiff, outVarName(`outTable2'_delta_InfoDiff) treat1(jla_1_sk) treat0(jla_0_sk) row(7);
	
***************************************************************;	
* ANNOTATION for panel B AND CLOSING;
***************************************************************;
replace `outTable'_row = "Source: " + "`filename'" if _n == 28; 
replace `outTable'_row = "Generated: `c(current_time)' `c(current_date)'" if _n == 29;

local outfile = "excel\\`outTable'.out";
outsheet `outTable'_* using `outfile' if _n<30, replace;

replace `outTable2'_row = "Standard errors clustered at the individual level" if _n == 14;
replace `outTable2'_row = "Source: " + "`filename'" if _n == 15; 
replace `outTable2'_row = "Generated: `c(current_time)' `c(current_date)'" if _n == 16;

outsheet `outTable2'_* using excel\kendraEffectsTransUp.out if _n<17, replace;

log close;
