%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Dynamic joint best response functions
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This builds on the individul best response functions
% Both agents optimize and we find all fixed points (Nash Equilib)

clear
tic
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   Income distribution setup
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
gameY = [80     80;
         70    100;
         50    140;
         40    160;
         30    180;
         20    200;
         10    240;
          0    280];

bmarkrho = [2.50 1.28 0.70 0.52 0.39 0.31 0.22 0.08];
%bmarkrho = [2.5];

transCPO = zeros(8,8);

incomeMakerOwn =  [0 0 1 1;
                   1 1 0 0];   

incomeMakerOther =  [0 1 0 1;
                    1 0 1 0];   
               
               
% Other inputs
Db = 40;
prob = [0.25 0.25 0.25 0.25];
dyn = 1;    
r = 0.33333;                                                                                        % Discount rate
delta = 1/(1+r);                                                                                    % Implied continuation probability
probcheck = sum(prob);

if probcheck==1
    disp('>>> Probability matrix validated');
    disp('   ');
else
    error('Probabilty matrix does not sum to 1');
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Input Values
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%investLoopRange = importdata('investLoopRange.csv');
[iter ~] = size(gameY);
[rhoIter ~] = size(bmarkrho');
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Other opening matter
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
aCount = 1:iter;
loopCount = 1; % Initialize loopcounter

scrsz = get(0,'ScreenSize');
replicator = ones(iter,1);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% JOINT LIABILITY WITH ONLY DEBT REQUIRED TRANSFERS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Calculate best response a(i) for all possible a(-i)
% Earlier version put all these sections in separate function files but
% this was hard to follow
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Defining some functions
% Calculate best response functions
% Calculating the matrices in order is 3x faster than calling the nested
% functions.

sizeCheck = 64;

outParameters = zeros(1,4);
outIL = zeros(sizeCheck,9);
outJL1 = zeros(sizeCheck,8);
outJL2 = zeros(sizeCheck,8);
outJL3 = zeros(sizeCheck,8);
outJL4 = zeros(sizeCheck,8);

outJL1short = zeros(sizeCheck,7);
outJL2short = zeros(sizeCheck,7);
outJL3short = zeros(sizeCheck,7);
outJL4short = zeros(sizeCheck,7);


for rho1Loop = 1: rhoIter
    for rho2Loop = 1: 1: rhoIter
        p1 = bmarkrho(rho1Loop);
        p2 = bmarkrho(rho2Loop);

        brA=zeros(iter,1);
        brB=zeros(iter,1);

        for i=1:iter
            ownInc = gameY * incomeMakerOwn;
            otherInc = replicator*gameY(i,:)*incomeMakerOther;
            pairInc = ownInc + otherInc;         % Combined income will be used for repayment calculation

            transJL = min(Db-otherInc,ownInc-Db).*(ownInc>=Db).*(otherInc<Db)-min(Db-ownInc,otherInc-Db).*(otherInc>=Db).*(ownInc<Db);
            % Transfers here defined as transfer from A to B.  Assume only required
            % transfers are made
            ownIncAfterTransJL = ownInc - transJL;   % A's income after net transfers

            repayJL = min(ownIncAfterTransJL,Db);     % Amount repaid by A under JL

            ownIncAfterRepayJL = ownIncAfterTransJL - repayJL;  % A's JL income after transfers and repayment

            contJL = pairInc >= 2*Db;   % Did the group repay for each state of the world

            contProbJL = contJL * prob';  % Repayment outcomes weighted by state probabilities

            uJLMatrix = util(ownIncAfterRepayJL,p1); % Calls utility function.  Calcs utility for each state

            uJL = uJLMatrix * prob';  % Instantaneous VNM utility

            vJLA = uJL./(1-delta*contProbJL); % Discounted value function
            [~,rowMaxJLA] = max(vJLA);
            brA(i) = rowMaxJLA;

            %   For B
            ownInc = gameY * incomeMakerOwn;
            otherInc = replicator*gameY(i,:)*incomeMakerOther;
            pairInc = ownInc + otherInc;         % Combined income will be used for repayment calculation

            transJL = min(Db-otherInc,ownInc-Db).*(ownInc>=Db).*(otherInc<Db)-min(Db-ownInc,otherInc-Db).*(otherInc>=Db).*(ownInc<Db);
            % Transfers here defined as transfer from B to A.  Assume only required
            % transfers are made
            ownIncAfterTransJL = ownInc - transJL;   % B's income after net transfers

            repayJL = min(ownIncAfterTransJL,Db);     % Amount repaid by B under JL

            ownIncAfterRepayJL = ownIncAfterTransJL - repayJL;  % B's JL income after transfers and repayment

            contJL = pairInc >= 2*Db;   % Did the group repay for each state of the world

            contProbJL = contJL * prob';  % Repayment outcomes weighted by state probabilities

            uJLMatrix = util(ownIncAfterRepayJL,p2); % Calls utility function.  Calcs utility for each state

            uJL = uJLMatrix * prob';  % Instantaneous VNM utility

            vJLB = uJL./(1-delta*contProbJL); % Discounted value function
            [~,rowMaxJLB] = max(vJLB);
            brB(i) = rowMaxJLB;
        end

        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        % Finds fixed points (Nash equilibria)
        % There may be a more efficient way to do lookups than find function
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        brABA=zeros(iter,1);
        brBAB=zeros(iter,1);
        for i=1:iter
            brABA(i) = brA(brB(i));
            brBAB(i) = brB(brA(i));
        end

        fixedPointA = aCount(find(brABA==aCount'))';

        fixedPointB = zeros(length(fixedPointA),1); % Creates storage blank for B's best response
        ufp        = zeros(length(fixedPointA),5); % Creates storage blank for utility measures

        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        % Caculate individual utility at each NE
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        for i=1:length(fixedPointA)
            fixedPointB(i) = brB(fixedPointA(i));
                % Calculate A's utility (this is inefficient coding but done for clarity)
               ownInc = gameY(fixedPointA(i),:) * incomeMakerOwn;
               otherInc = gameY(fixedPointB(i),:) * incomeMakerOther;
               pairInc = ownInc + otherInc;
               transJL = min(Db-otherInc,ownInc-Db).*(ownInc>=Db).*(otherInc<Db)-min(Db-ownInc,otherInc-Db).*(otherInc>=Db).*(ownInc<Db);
               ownIncAfterTransJL = ownInc - transJL;                                               % B's income after net transfers
               repayJL = min(ownIncAfterTransJL,Db);
               ownIncAfterRepayJL = ownIncAfterTransJL - repayJL;
               contJL = pairInc >= 2*Db;                                                            % Did the group repay for each state of the world
               contProbJL = contJL * prob';                                                         % Repayment outcomes weighted by state probabilities
               uJLMatrix = util(ownIncAfterRepayJL,p1);                                             % Calls utility function.  Calcs utility for each state
               uJLA = uJLMatrix * prob';                                                            % Instantaneous VNM utility
               vJLA = uJLA./(1-delta*contProbJL);                                                   % Discounted value function
               
               % Calculate A's utility (this is inefficient coding but done for clarity)
               ownInc = gameY(fixedPointB(i),:) * incomeMakerOwn;
               otherInc = gameY(fixedPointA(i),:) * incomeMakerOther;
               pairInc = ownInc + otherInc;
               transJL = min(Db-otherInc,ownInc-Db).*(ownInc>=Db).*(otherInc<Db)-min(Db-ownInc,otherInc-Db).*(otherInc>=Db).*(ownInc<Db);
               ownIncAfterTransJL = ownInc - transJL;                                               % B's income after net transfers
               repayJL = min(ownIncAfterTransJL,Db);
               ownIncAfterRepayJL = ownIncAfterTransJL - repayJL;
               contJL = pairInc >= 2*Db;                                                            % Did the group repay for each state of the world
               contProbJL = contJL * prob';                                                         % Repayment outcomes weighted by state probabilities
               uJLMatrix = util(ownIncAfterRepayJL,p2);                                             % Calls utility function.  Calcs utility for each state
               uJLB = uJLMatrix * prob';                                                            % Instantaneous VNM utility
               vJLB = uJLB./(1-delta*contProbJL);                                                   % Discounted value function

             ufp(i,1) = vJLA;
             ufp(i,2) = uJLA;
 
             ufp(i,3) = vJLB;
             ufp(i,4) = uJLB;
             ufp(i,5) = contProbJL;
        end

                  
%                 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                 % Summary Data
%                 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
                 parameterSummary = [p1 p2];
                 fixedpoint = [fixedPointA fixedPointB ufp];
                 [numJLFixedPoints ~] = size(fixedpoint);
                 
                 outParameters(loopCount,:) = [loopCount parameterSummary numJLFixedPoints];

                
                if numJLFixedPoints == 0
                    outJL1short(loopCount,:) = [NaN(1,7)];
                    outJL2short(loopCount,:) = [NaN(1,7)];
                    outJL3short(loopCount,:) = [NaN(1,7)];
                    outJL4short(loopCount,:) = [NaN(1,7)];
                elseif numJLFixedPoints == 1
                    outJL1short(loopCount,:) = [fixedpoint(1,:)];
                    outJL2short(loopCount,:) = [NaN(1,7)];
                    outJL3short(loopCount,:) = [NaN(1,7)];
                    outJL4short(loopCount,:) = [NaN(1,7)];
                elseif numJLFixedPoints == 2
                    outJL1short(loopCount,:) = [fixedpoint(1,:)];
                    outJL2short(loopCount,:) = [fixedpoint(2,:)];
                    outJL3short(loopCount,:) = [NaN(1,7)];
                    outJL4short(loopCount,:) = [NaN(1,7)];
                elseif numJLFixedPoints == 3
                    outJL1short(loopCount,:) = [fixedpoint(1,:)];
                    outJL2short(loopCount,:) = [fixedpoint(2,:)];
                    outJL3short(loopCount,:) = [fixedpoint(3,:)];
                    outJL4short(loopCount,:) = [NaN(1,7)];
                else
                    outJL1short(loopCount,:) = [fixedpoint(1,:)];
                    outJL2short(loopCount,:) = [fixedpoint(2,:)];
                    outJL3short(loopCount,:) = [fixedpoint(3,:)];
                    outJL4short(loopCount,:) = [999*ones(1,7)];
                end
                %                 
                 loopCount = loopCount + 1;
%                 
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        % Display
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
                 disp('*************************************');
                 disp('Parameter Summary');
                  disp('      p1        p2      delta');
                 disp('    ------    ------    ------');
                 disp(parameterSummary);
                 
                 disp('*************************************');
                 disp('Fixed points for Joint Liability with Debt Repayment Transfer');
                 disp('      aA        aB        VA        UA        VB        UB      P(rpyB)');
                 disp('    ------    ------    ------    ------    ------    ------    ------');
                 disp(fixedpoint);
    end
end
        
outJL1 = [outParameters outJL1short];
outJL2 = [outParameters outJL2short];
outJL3 = [outParameters outJL3short];
outJL4 = [outParameters outJL4short];

outJLBig = [outParameters outJL1short outJL2short outJL3short outJL4short];


 disp('*************************************');
 disp(' ');
 disp('Joint Liabilty, Required Transfers Only, Fixed Points, #1');
 disp('Displays all fixed points.  Row set to zero if none');
 disp('      iter       p1        p2        aA        aB        VA        UA        VB        UB      P(rpy)');
 disp('     ------    ------    ------    ------    ------    ------    ------    ------    ------    ------');
 disp(outJL1);

disp('*************************************');
disp(' ');
disp('Joint Liabilty, Required Transfers Only, Fixed Points, #2');
disp('Displays all fixed points.  Row set to zero if none');
disp('      iter       p1        p2        aA        aB        VA        UA        VB        UB      P(rpy)');
disp('     ------    ------    ------    ------    ------    ------    ------    ------    ------    ------');
disp(outJL2);

disp('*************************************');
disp(' ');
disp('Joint Liabilty, Required Transfers Only, Fixed Points, #3');
disp('Displays all fixed points.  Row set to zero if none');a
disp('      iter       p1        p2        aA        aB        VA        UA        VB        UB      P(rpy)');
disp('     ------    ------    ------    ------    ------    ------    ------    ------    ------    ------');
disp(outJL3);

disp('*************************************');
disp(' ');
disp('Joint Liabilty, Required Transfers Only, Fixed Points, Notes');
disp('999 indicates more than 3 fixed points');
disp('    iter ');
disp('    ----  ---   ---   ---   ---   ---   ---   ---   ---');
disp(outJL4);
toc    
    
csvwrite('C:\Users\fischerg\Documents\Docs\Research\groupLiability\MATLAB2012\jlAutarkyValues',outJLBig)    
