%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Individual Best Response Functions
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Input Values
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
tic
gameY = [80     80;
         70    100;
         50    140;
         40    160;
         30    180;
         20    200;
         10    240;
          0   280];
D = 40;               
      
bmarkrho = [2.50 1.28 0.70 0.52 0.39 0.31 0.22 0.00];      

pH = 0.5;                                                                                           % Probability that risky asset is successful
                                                                                                    
delta = 0.75;                                                                                       % Continuation probability;
beta = (1-delta)/delta;                                                                             % Implied discount factor;


choiceA = (1:8)';
choiceB = 5;

muVector = zeros(3,8);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Other opening matter
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
iter=length(gameY);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% INDIVIDUAL & JOINT LIABILITY WITH AUTARKIC TRANSFERS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
for bmarkA = 1:8
    p1 = bmarkrho(bmarkA);                                                                          % Risk aversion index of 1 (assumes CRRA)
    probTheta = [pH^2 pH*(1-pH) (1-pH)*pH (1-pH)^2];                                                % Prob for states HH HL LH LL

    probTheta = [pH^2 pH*(1-pH) (1-pH)*pH (1-pH)^2];                                                % Prob for states HH HL LH LL

    ownInc = [gameY(:,2) gameY(:,2) gameY(:,1) gameY(:,1)] ;                                        % Own income in each state for each choice  
    otherInc = ones(iter,1)*[gameY(choiceB,2) gameY(choiceB,1) gameY(choiceB,2) gameY(choiceB,1)];  % Other income for fixed aB
    pairInc = ownInc + otherInc;                                                                    % Combined income will be used for repayment calculation

    transJL = min(D-otherInc,ownInc-D).*(ownInc>=D).*(otherInc<D)-min(D-ownInc,otherInc-D).*(otherInc>=D).*(ownInc<D);
        % Transfers defined as transfer from A to B.  Assume only required
        % transfers are made
    ownIncAfterTransJL = ownInc - transJL;                                                          % A's income after net transfers

    repayJL = min(ownIncAfterTransJL,D);                                                            % Amount repaid by A under JL
    repayIL = min(ownInc,D);                                                                        % Amount repaid by A under IL

    ownIncAfterRepayJL = ownIncAfterTransJL - repayJL;                                              % A's JL income after transfers and repayment
    ownIncAfterRepayIL = ownInc - repayIL;                                                          % A's IL income after repayment (no transfers)

    contJL = pairInc >= 2*D;                                                                        % Did the group repay for each state of the world
    contIL = ownInc >=1*D;                                                                          % Did A repay for each state of the world

    contProbJL = contJL * probTheta';                                                               % Repayment outcomes weighted by state probabilities
    contProbIL = contIL * probTheta';

    uJLMatrix = util(ownIncAfterRepayJL,p1);                                                        % Calls utility function.  Calcs utility for each state
    uILMatrix = util(ownIncAfterRepayIL,p1);

    uJL = uJLMatrix * probTheta';                                                                   % Instantaneous VNM utility
    uIL = uILMatrix * probTheta';

    vJL = uJL./(1-delta*contProbJL);                                                                % Discounted value function
        [cMaxJL,rowMaxJL] = max(vJL);
        aMaxJL = choiceA(rowMaxJL);
    vIL = uIL./(1-delta*contProbIL);
        [cMaxIL,rowMaxIL] = max(vIL);
        aMaxIL = choiceA(rowMaxIL);
    scaleFactor = abs(1/(max(max(vJL),max(vIL))));
    plotMin = min(min(vJL),min(vIL))*scaleFactor * .98;

    changeRiskyInv = aMaxJL - aMaxIL;


    disp('********* START *****************');
    disp(['a bmark choice           :  ',num2str(bmarkA,'% 5.3f')]);
    disp(['a bmark rho              :  ',num2str(p1,'% 5.3f')]);
    disp('   ');
    disp(['a(A) in IL                :  ',num2str(aMaxIL,'% 5.3f')]);
    disp('*************************************');

    cHstar = ownIncAfterRepayIL(aMaxIL,1);
    cLstar = ownIncAfterRepayIL(aMaxIL,3);
    muRatio = cHstar^(-p1)/cLstar^(-p1);
    disp(['cH in IL                :  ',num2str(cHstar,'% 5.2f')]);
    disp(['cL in IL                :  ',num2str(cLstar,'% 5.2f')]);
    disp(['du/dc @ yH in IL        :  ',num2str(cHstar^(-p1),'% 5.2f')]);
    disp(['du/dc @ yL in IL        :  ',num2str(cLstar^(-p1),'% 5.2f')]);
    disp(['mu ratio                : ',num2str(muRatio,'%5.3f')]);
    disp('*************************************');
    muVector(1,bmarkA)=cHstar^(-p1);
    muVector(2,bmarkA)=cLstar^(-p1);
    muVector(3,bmarkA)=cHstar^(-p1)/cLstar^(-p1);
end
toc

lambdaH = zeros(8,8);
lambdaL = zeros(8,8);
for ia = 1:8
    for ib = 1:8
        lambdaH(ia,ib) = muVector(1,ia)/muVector(1,ib);
        lambdaL(ia,ib) = muVector(2,ia)/muVector(2,ib);
    end
end
lambdaAvg = (lambdaH + lambdaL) / 2;
xlswrite('C:\Users\fischerg\Documents\Docs\Research\groupLiability\MATLAB2012\lambdaAvg',lambdaAvg)
xlswrite('C:\Users\fischerg\Documents\Docs\Research\groupLiability\MATLAB2012\lambdaH',lambdaH)
xlswrite('C:\Users\fischerg\Documents\Docs\Research\groupLiability\MATLAB2012\lambdaL',lambdaL)