%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   Maximum Sustainable transfers
%   Loops over investment choices
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear;
tic


step = 0.001;
critvalue = step / 10;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   Income distribution setup
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
gameY = [80     80;
         70    100;
         50    140;
         40    160;
         30    180;
         20    200;
         10    240;
          0    280];

bmarkrho = [2.50 1.28 0.70 0.52 0.39 0.31 0.22 0.08];

transCPO = zeros(8,8);

% Loads lambda (autarkic pareto weight) matrix generated by file lambdaFinderFinal.m
% vJLMTPMatrix generated by bestResponseSingleFinal.m --> Export to jlAutarkyValues.xls
%   This file is processed in Excel file jlAutarkyValuesProcess.xlsx (more transparent than matlab
%   coding) and then saved manually as vJLMTPMatrix.csv
a%%% Selection for ABACUS
     lambda = xlsread('S:\GroupLiability\lambdaH');
     vJLMTPMatrix = csvread('S:\GroupLiability\vJLMTPMatrix.csv');

whatStart = zeros(4096,4);     
noSolutionStart = zeros(4096,1);
iLstart = zeros(4096,1);

% Other inputs
Db = 40;
prob = [0.25 0.25 0.25 0.25];
dyn = 1;    
r = 0.33333;                                                                                        % Discount rate
d = 1/(1+r);                                                                                        % Implied continuation probability
probcheck = sum(prob);

if probcheck==1
    disp('>>> Probability matrix validated');
    disp('   ');
else
    error('Probabilty matrix does not sum to 1');
end

% Loops across all bmark choices and game choices

for bmarkA = 8:8
    for bmarkB = 8:8
        for choiceA = 8:8
            for choiceB = 8:8
                outsideOptionRow = (bmarkA-1)*8+ bmarkB;
                disp(['Optimizing for *JL*, bmarkA==',num2str(bmarkA),', bmarkB==',num2str(bmarkB)...
                    ,', choiceA==',num2str(choiceA),', choiceB==',num2str(choiceB)]);
                wrow = choiceB + (choiceA-1)*8 + (bmarkB-1)*64 + (bmarkA-1)*512;
                
                y1 = gameY(choiceA,:);
                y2 = gameY(choiceB,:);
                
                rhoA = bmarkrho(bmarkA);                                                            % CRRA risk aversion index for individual 1
                rhoB = bmarkrho(bmarkB);                                                            % CRRA risk aversion index for individual 2
                
                
                probcheck = sum(prob);
                
                if probcheck==1
                    disp('>>> Probability matrix validated');
                    disp('   ');
                else
                    error('Probabilty matrix does not sum to 1');
                end
                
                yAmat=  [y1(2) y1(2) y1(1) y1(1)];
                yBmat=  [y2(2) y2(1) y2(2) y2(1)];
                
                yTot = yAmat + yBmat;
                yD = max(yTot - 2*Db,0);
                
                cAaut = max(yAmat-Db,0);                                                            % Autarky consumption for A (after repayment)
                cBaut = max(yBmat-Db,0);                                                            % Autarky consumption for B (after repayment)
                
                pAaut = 1-dyn*(1-sum(prob.*(yAmat>=Db)));                                           % prob of repayment in autarky
                pBaut = 1-dyn*(1-sum(prob.*(yBmat>=Db)));                                           % prob of repayment in autarky
                
                vAaut = (1-d)/(1-d*pAaut)*sum(prob.*util(cAaut,rhoA));
                vBaut = (1-d)/(1-d*pBaut)*sum(prob.*util(cBaut,rhoB));
                
                Wjl = (max(Db-yBmat,0).*((yAmat+yBmat)>=(2*Db))) - (max(Db-yAmat,0).*((yAmat+yBmat)>=(2*Db)));
                yAjl = yAmat - Wjl;
                yBjl = yBmat + Wjl;
                
                cAjl = max(yAjl - Db,0);
                cBjl = max(yBjl - Db,0);
                
                cAmat=cAjl;
                cBmat=cBjl;
                
                L = lambda(bmarkA,bmarkB); 
                                
                uAbar = sum(prob.*util(cAmat,rhoA)); % per period autarky utility
                uBbar = sum(prob.*util(cBmat,rhoB)); % per period autarky utility
                
                lambdaAut = (cAmat.^(-rhoA))./(cBmat.^(-rhoB));
                
                vAjl = vJLMTPMatrix(outsideOptionRow,1);
                vBjl = vJLMTPMatrix(outsideOptionRow,2);
                
                
                % This section calculates the optimal risk sharing transfers at the chosen lambda
                % This next line will need to be changed to "optimal" risk sharing transfers
                % Will be based on a lambda
                % then need to have equal ratio in all states of world
                % Solution is that cA + L^(1/rhoB)*cA^(rhoA/rhoB)=max(y-2*Db,0) in all states of the world
                % then t =  yA - Db - cA
                Wequal = (yAjl - yBjl)/2;   
                localL = L;
                cmax = max(max(gameY))*2;
                cposs = (0:0.01:cmax)';
                lambdaLoopSize = 1000;
                lambdaLoopStep = 0.01;
                noSolution = 0;
                
                for iL = 1:lambdaLoopSize
                    iLstart(wrow) = iL;
                    consAMat = zeros(1,4);  
                    for isub = 1:4
                        [diff cI] = min(abs(cposs + localL^(1/rhoB)*cposs.^(rhoA/rhoB)-yD(isub)));
                        consAMat(isub) = cposs(cI);
                    end
                    What = (yAjl - consAMat - Db).*(yTot>=(2*Db)) + Wjl;
                    whatStart(wrow,:)=What;
                    
                    pAtemp = 1-dyn*(1-sum(prob.*((yAmat-What)>=Db).*((yBmat+What)>=Db)));           % prob of repayment in jl
                    pBtemp = 1-dyn*(1-sum(prob.*((yBmat+What)>=Db).*((yAmat-What)>=Db)));           % prob of repayment in jl
                    
                    vAtemp = (1-d)/(1-d*pAtemp)*sum(prob.*util(max(yAmat-What-Db,0),rhoA));
                    vBtemp = (1-d)/(1-d*pBtemp)*sum(prob.*util(max(yBmat+What-Db,0),rhoB));
                    if mod(iL,100)==0 || iL==1
                        disp(['Iter: ',num2str(iL),'. Checking feasibility for L== ',num2str(localL)]);
                    end
                    if (vAtemp >= vAjl) && (vBtemp >= vBjl)
                        disp(['ooo Full transfer satisfies PC for L ',num2str(localL)]);
                        break
                    elseif vAtemp < vAjl && vBtemp < vBjl;
                        disp(['xxx Both agents PCs bind at optimal for L ',num2str(localL)]);
                        noSolutionStart(wrow)= 1;
                        disp('xxx NO FEASIBLE SOLUTION');
                        break
                    elseif vAtemp < vAjl;
                        localL = L*(1+lambdaLoopStep)^(-iL);
                    elseif vBtemp < vBjl;
                        localL = L*(1+lambdaLoopStep)^iL;
                    end
                    if iL==lambdaLoopSize
                        disp('XXX WARN: NO SOLUTION FOUND');
                    end
                end
                
                toc
                
            end
        end
    end
end

        
        
%%% Selection for ABACUS server
      csvwrite('S:\GroupLiability\whatStart-altOut-JL2012.csv',whatStart);
      csvwrite('S:\GroupLiability\noSolutionStart-altOut-JL2012.csv',noSolutionStart);
      csvwrite('S:\GroupLiability\iLstart-altOut-JL2012.csv',iLstart);
 
toc

