%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   Maximum Sustainable transfers
%   Loops over investment choices
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear;
tic


step = 0.001;
critvalue = step / 10;
swap = [-1 0 0 0; 0 0 -1 0; 0 -1 0 0; 0 0 0 -1];
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   Income distribution setup
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
gameY = [80     80;
         70    100;
         50    140;
         40    160;
         30    180;
         20    200;
         10    240;
          0    280];

bmarkrho = [2.50 1.28 0.70 0.52 0.39 0.31 0.22 0.08];

transCPO = zeros(8,8);

% Loads lambda (autarkic pareto weight) matrices generated by file ownChoiceFinal.m
%%% Selection for ABACUS
    lambda = xlsread('S:\GroupLiability\lambdaH');
    whatStart        = csvread('S:\GroupLiability\whatStart-IL.csv');
    noSolutionStart  = csvread('S:\GroupLiability\noSolutionStart-IL.csv');
    iLstart          = csvread('S:\GroupLiability\iLstart-IL.csv');


maxTrans_HH = zeros(64,128);                                                                        % Storage matrices for maximum transfers. First 64 columns IL.  Col 65-128 for JL
maxTrans_HL = zeros(64,128);
maxTrans_LH = zeros(64,128);
maxTrans_LL = zeros(64,128);
maxTrans_ck = zeros(64,128);


% Other inputs
Db = 40;
prob = [0.25 0.25 0.25 0.25];
dyn = 1;    
r = 0.33333;                                                                                        % Discount rate
d = 1/(1+r);                                                                                        % Implied continuation probability
probcheck = sum(prob);

if probcheck==1
    disp('>>> Probability matrix validated');
    disp('   ');
else
    error('Probabilty matrix does not sum to 1');
end

% Loops across all bmark choices and game choices

for bmarkA = 1:8
    for bmarkB = 1:8
        for choiceA = 1:8
            for choiceB = 1:8
                disp(['Optimizing for IL, bmarkA==',num2str(bmarkA),', bmarkB==',num2str(bmarkB)...
                    ,', choiceA==',num2str(choiceA),', choiceB==',num2str(choiceB)]);
                col = (bmarkA-1)*8 + choiceA;
                row = (bmarkB-1)*8 + choiceB;
                maxTrans_ck(row,col)=1;
                
        y1 = gameY(choiceA,:);
        y2 = gameY(choiceB,:);

        rhoA = bmarkrho(bmarkA);                                                                    % CRRA risk aversion index for individual 1
        rhoB = bmarkrho(bmarkB);                                                                    % CRRA risk aversion index for individual 2


        probcheck = sum(prob);

        if probcheck==1
            disp('>>> Probability matrix validated');
            disp('   ');
        else
            error('Probabilty matrix does not sum to 1');
        end

        yAmat=  [y1(2) y1(2) y1(1) y1(1)];
        yBmat=  [y2(2) y2(1) y2(2) y2(1)];
                
        yTot = yAmat + yBmat;
        yD = max(yTot - 2*Db,0);
        
        cAaut = max(yAmat-Db,0);                                                                    % Autarky consumption for A (after repayment)
        cBaut = max(yBmat-Db,0);                                                                    % Autarky consumption for B (after repayment)
        
        cAjl = max(yAmat-Db+min(yBmat-Db,0).*(yD>=0),0);
        cBjl = max(yBmat-Db+min(yAmat-Db,0).*(yD>=0),0);
        
         cAmat=cAaut;
         cBmat=cBaut;
         
       
        L = lambda(bmarkA,bmarkB); 
                
        uAbar = sum(prob.*util(cAmat,rhoA));                                                        % per period autarky utility
        uBbar = sum(prob.*util(cBmat,rhoB));                                                        % per period autarky utility

        pAaut = 1-dyn*(1-sum(prob.*(yAmat>=Db)));                                                   % prob of repayment in autarky
        pBaut = 1-dyn*(1-sum(prob.*(yBmat>=Db)));                                                   % prob of repayment in autarky
        
        rAbar = (d*pAaut)/(1-d*pAaut);
        rBbar = (d*pBaut)/(1-d*pBaut);
        
        lambdaAut = (cAmat.^(-rhoA))./(cBmat.^(-rhoB));

        vAaut = (1-d)/(1-d*pAaut)*sum(prob.*util(cAmat,rhoA));
        vBaut = (1-d)/(1-d*pBaut)*sum(prob.*util(cBmat,rhoB));

        % This section calculates the optimal risk sharing transfers at the chosen lambda
        % Will be based on a lambda
        % then need to have equal ratio in all states of world
        % Solution is that cA + L^(1/rhoB)*cA^(rhoA/rhoB)=max(y-2*Db,0) in all states of the world
        % then t =  yA - Db - cA
        Wequal = (yAmat - yBmat)/2;   % Equal split transfers
        localL = L;
        cmax = max(max(gameY))*2;
        cposs = (0:0.01:cmax)';
        lambdaLoopSize = 1000;
        lambdaLoopStep = 0.01;
        
        wrow = choiceB + (choiceA-1)*8 + (bmarkB-1)*64 + (bmarkA-1)*512;
        noSolution = noSolutionStart(wrow);
        iL = iLstart(wrow);
        What = whatStart(wrow,:);
                
        toc
 
        
        Wout = What;                                                                                % Wout will hold the iterated maximum transfer
        aIcIn = [0 0 0 0];
        bIcIn = [0 0 0 0];
        
        crit = 1;
        iter = 0;
        disp(['Iter: ',num2str(iter),'. Transfer Check== ',sprintf('%9.3f',[Wout])]);
        
        WAchangeLast = 1; 
        WBchangeLast = 1;
        changeLast = 1;
        changeLast1 = 1;
        changeLast2 = 1;
        maxIter = max(abs(What))/step;
        
        while crit > critvalue;
        %while iter <10
            iter = iter + 1;
            Win = Wout;     

            yAt = yAmat - Win;                                                                      % 1's income after transfers
            pAt = 1-dyn*(1-sum(prob.*(yAt>=Db)));                                                   % prob that 1 repays
            cAt = max(yAt-Db,0);                                                                    % 1's consumption (subject to LL)
            rAt = (d*pAt)/(1-d*pAt);
            
            cBt = max(yBmat + Win - Db,0);                                                           % 2's consumption (subject to LL)

            if iter == 1
                lambdaStart = (cAt.^(-rhoA))./(cBt.^(-rhoB));
            end
            
            % Calculate A's maximum utility increment
            if rhoA>1
                incrA = min(util(cAmat,rhoA) - rAt * sum(sum(prob.*util(cAt,rhoA))) + rAbar * uAbar,0);
            else
                incrA = max(util(cAmat,rhoA) - rAt * sum(sum(prob.*util(cAt,rhoA))) + rAbar * uAbar,0);
            end
                        
            WAmax = cAmat - invU(incrA,rhoA);
            if vAaut == -Inf
                WAmax = max(cAmat-0.1,0);
            end
            
            % Calculate B's maximum utility increment based on Win
            yBt = yBmat + Win;
            pBt = 1-dyn*(1-sum(sum(prob.*(yBt>=Db))));                                              % prob that 2 repays
            cBt = max(yBt-Db,0);                                                                    % 2's consumption (subject to LL)
            rBt = (d*pBt)/(1-d*pBt);
            if rhoB>1
                incrB = min(util(cBmat,rhoB) - rBt * sum(sum(prob.*util(cBt,rhoB))) + rBbar * uBbar,0);
            else
                incrB = max(util(cBmat,rhoB) - rBt * sum(sum(prob.*util(cBt,rhoB))) + rBbar * uBbar,0);
            end
            WBmax = cBmat - invU(incrB,rhoB);
            if vBaut == -Inf
                WBmax = max(cBmat-0.1,0);
            end
            lambdaRat = (cAt.^(-rhoA))./(cBt.^(-rhoB));
            WAchange = -(sum(WAmax<Win)>0).*(WBmax>-Win)*step;
            WBchange = (sum(WBmax<-Win)>0).*(WAmax>Win)*step;
            
            Wtemp = Wout;
            Wout = Win + WAchange + WBchange;
            
            % Confirm transfer wouldn't cause new default
            causeAdefault = (yAmat-Wout-Db<0).*(yAmat-Wtemp-Db>=0);
            causeBdefault = (yBmat+Wout-Db<0).*(yBmat+Wtemp-Db>=0);
            Wout = (1-causeAdefault).*Wout + (causeAdefault).*Wtemp;
            Wout = (1-causeBdefault).*Wout + (causeBdefault).*Wtemp;
            
            % No transfers FROM individual with income less than debt;
            Wout = (yAmat>=Db).*Wout + (1-(yAmat>=Db)).*min(0,Wout);
            Wout = (yBmat>=Db).*Wout + (1-(yBmat>=Db)).*max(0,Wout);
            
            % No transfers if total income is insufficent to repay both loans;
            Wout = (yTot>=(2*Db)).*Wout;
            
            % Check that change doesn't break an IC that was previously satsified
            ckpAt = 1-dyn*(1-sum(prob.*((yAmat-Wout)>=Db)));
            ckpBt = 1-dyn*(1-sum(prob.*((yBmat+Wout)>=Db)));
            if rhoA>1
                checkWAmax = cAmat - invU(min(util(cAmat,rhoA) - (d*ckpAt)/(1-d*ckpAt) * sum(prob.*util(max(yAmat-Wout-Db,0),rhoA)) + rAbar * uAbar,0),rhoA);
            else
                checkWAmax = cAmat - invU(max(util(cAmat,rhoA) - (d*ckpAt)/(1-d*ckpAt) * sum(prob.*util(max(yAmat-Wout-Db,0),rhoA)) + rAbar * uAbar,0),rhoA);
            end
            if rhoB>1
                checkWBmax = cBmat - invU(min(util(cBmat,rhoB) - (d*ckpBt)/(1-d*ckpBt) * sum(prob.*util(max(yBmat+Wout-Db,0),rhoB)) + rBbar * uBbar,0),rhoB);
            else
                checkWBmax = cBmat - invU(max(util(cBmat,rhoB) - (d*ckpBt)/(1-d*ckpBt) * sum(prob.*util(max(yBmat+Wout-Db,0),rhoB)) + rBbar * uBbar,0),rhoB);
            end
            
            aIcOut = checkWAmax >= Wout;
            bIcOut = checkWBmax >= -Wout;
            aIcIn  = WAmax >= Win;
            bIcIn = WBmax >= -Win;
             Wout = ((aIcOut==0).*(aIcIn==1)).*Win + (1-((aIcOut==0).*(aIcIn==1))).*Wout;
             Wout = ((bIcOut==0).*(bIcIn==1)).*Win + (1-((bIcOut==0).*(bIcIn==1))).*Wout;
            Wtemp=Wout - (sum((Wout-Win)<0)>1).*(Wout-Win).*((Wout-Win)<0).*(lambdaRat==min(lambdaRat))*(sum((lambdaRat==min(lambdaRat)))==1) ...
                      -(sum((Wout-Win)>0)>1).*(Wout-Win).*((Wout-Win)>0).*(lambdaRat==max(lambdaRat))*(sum((lambdaRat==max(lambdaRat)))==1);
            if isequal(Wout-Win+changeLast1,[0 0 0 0]) || isequal(Wtemp-Win+changeLast1,[0 0 0 0])
                Wout=Wtemp;
            end
            
            WAchangeLast=sum(WAchange);
            WBchangeLast=sum(WBchange);
            changeLast3 = changeLast2;
            changeLast2 = changeLast1;
            changeLast1 = changeLast;
            changeLast = (Win-Wout);
            noChange3 = (sum(abs(changeLast+changeLast1))==0)*(sum(abs(changeLast+changeLast1+changeLast2+changeLast3))==0);
                        
            lambdaRat = ((max(yAmat-Wout-Db,0)).^(-rhoA))./((max(yBmat+Wout-Db,0)).^(-rhoB));
            crit = sum((sum((WBmax>=-Wout).*(WAmax>=Wout))~=4).*max(max(abs(WAchange),abs(WBchange)),max(abs(Win-Wout)))); 
            if mod(iter,10000) == 0 
                disp(['Iter: ',num2str(iter),'. Transfer Check== ',sprintf('%9.3f',[Wout])]);
            end
            if iter> maxIter || iL==lambdaLoopSize || noSolution==1 || noChange3==1
                break
            end
        end

        WoutFin = Wout;
        vAtemp = (1-d)/(1-d*(1-dyn*(1-sum(prob.*((yAmat-Wout)>=Db)))))*sum(prob.*util(max(yAmat-Wout-Db,0),rhoA));
        vBtemp = (1-d)/(1-d*(1-dyn*(1-sum(prob.*((yBmat+Wout)>=Db)))))*sum(prob.*util(max(yBmat+Wout-Db,0),rhoB));
        
        if vAaut > vAtemp
            disp('>>> WARNING: No sustainable transfer satisfies As participation constraint');
            maxTrans_ck(row,col)=-999;
            WoutFin = [0 0 0 0];
        end;
        if vBaut > vBtemp
            disp('>>> WARNING: No sustainable transfer satisfies Bs participation constraint');
           maxTrans_ck(row,col)=-999;
            WoutFin = [0 0 0 0];
        end;
       
        if vAtemp == -Inf
            disp('>>> WARNING: No sustainable transfer satisfies As participation constraint (-Inf)');
            maxTrans_ck(row,col)=-888;
            WoutFin = [0 0 0 0];
        end;
        if vBtemp == -Inf
            disp('>>> WARNING: No sustainable transfer satisfies Bs participation constraint (-Inf)');
            maxTrans_ck(row,col)=-888;
            WoutFin = [0 0 0 0];
        end;
        if iter> maxIter || iL==lambdaLoopSize || noSolution==1
             disp('>>> WARNING: Could not find stable solution');
                 maxTrans_ck(row,col)=-777;
             WoutFin = [0 0 0 0];
        end;
        if noChange3==1
             disp('>>> WARNING: Three iterations without a change');
                 maxTrans_ck(row,col)=-666;
            WoutFin = [0 0 0 0];
        end;
        
        cAfull = max(yAmat-What-Db,0);
        cBfull = max(yBmat+What-Db,0);

        cAsust = max(yAmat-WoutFin-Db,0);
        cBsust = max(yBmat+WoutFin-Db,0);
        
        cAbestSearch = max(yAmat-Wout-Db,0);
        cBbestSearch = max(yBmat+Wout-Db,0);

        pAfull = 1-dyn*(1-sum(prob.*((yAmat-What)>=Db)));                                           % prob of repayment in full insurance
        pBfull = 1-dyn*(1-sum(prob.*((yBmat+What)>=Db)));                                           % prob of repayment in full insurance

        pAsust = 1-dyn*(1-sum(prob.*((yAmat-WoutFin)>=Db)));                                        % prob of repayment in max sustainable
        pBsust = 1-dyn*(1-sum(prob.*((yBmat+WoutFin)>=Db)));                                        % prob of repayment in max sustainable

        pAbestSearch = 1-dyn*(1-sum(prob.*((yAmat-Wout)>=Db)));                                     % prob of repayment in max sustainable
        pBbestSearch = 1-dyn*(1-sum(prob.*((yBmat+Wout)>=Db)));                                     % prob of repayment in max sustainable

        vAfull = (1-d)/(1-d*pAfull)*sum(prob.*util(cAfull,rhoA));
        vBfull = (1-d)/(1-d*pBfull)*sum(prob.*util(cBfull,rhoB));

        vAsust = (1-d)/(1-d*pAsust)*sum(prob.*util(cAsust,rhoA));
        vBsust = (1-d)/(1-d*pBsust)*sum(prob.*util(cBsust,rhoB));
        
        vAbestSearch = (1-d)/(1-d*pAbestSearch)*sum(prob.*util(cAbestSearch,rhoA));
        vBbestSearch = (1-d)/(1-d*pBbestSearch)*sum(prob.*util(cBbestSearch,rhoB));
                
                maxTrans_HH(row,col)=WoutFin(1);
                maxTrans_HL(row,col)=WoutFin(2);
                maxTrans_LH(row,col)=WoutFin(3);
                maxTrans_LL(row,col)=WoutFin(4);
                disp(['>>>Iter: ',num2str(iter),'. Transfer:',sprintf('%9.3f',[WoutFin])]);
                toc
                disp('    ');
                disp('********************');
                
            end
        end
    end
end

%%% Selection for ABACUS server
    csvwrite('S:\GroupLiability\CPOTransHH-IL6.csv',maxTrans_HH);
    csvwrite('S:\GroupLiability\CPOTransHL-IL6.csv',maxTrans_HL);
    csvwrite('S:\GroupLiability\CPOTransLH-IL6.csv',maxTrans_LH);
    csvwrite('S:\GroupLiability\CPOTransLL-IL6.csv',maxTrans_LL);
    csvwrite('S:\GroupLiability\CPOTransCheck-IL6.csv',maxTrans_ck);
 
toc

