clear;
tic


step = 0.001;
critvalue = step / 10;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   Simple reciprocal debt calculations for symmetric players
%   Similar in spirit to Coate & Ravallion
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   Income distribution setup
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
gameY = [80     80;
         70    100;
         50    140;
         40    160;
         30    180;
         20    200;
         10    240;
          0    280];
      
pRange=[0.2 0.3 0.4 0.5 0.6 0.7 0.8 0.9];


iterC = 8;
iterP = length(pRange);

outTran = zeros(iterC,iterP);
outAut =    zeros(iterC,iterP);
outSust =    zeros(iterC,iterP);
outFull =    zeros(iterC,iterP);

Db = 40;

prob = [0.25    0.25;
        0.25    0.25];

dyn = 1;        						% 1 is default.  0 removes default incentive (always borrow)
r = 0.33333;       						% Discount rate
d = 1/(1+r);    						% Implied continuation probability


for iC = 1:iterC
    for iP = 1:iterP
        
        choice1 = iC;
        choice2 = iC;  

        y1 = gameY(choice1,:);
        y2 = gameY(choice2,:);

        p1 = pRange(iP);  	  				% CRRA risk aversion index for individual 1
        p2 = p1;    		  				% CRRA risk aversion index for individual 2


        probcheck = sum(sum(prob));

        if probcheck==1
            disp('>>> Probability matrix validated');
            disp('   ');
        else
            error('Probabilty matrix does not sum to 1');
        end

        y1mat=  y1' * ones(1,length(y2));   			% Autarky income for 1
        y2mat=  ones(length(y1),1) * y2;    			% Autarky income for 2

        c1mat = max(y1mat-Db,0);    				% Autarky consumption for 1 (after repayment)
        c2mat = max(y2mat-Db,0);    				% Autarky consumption for 2 (after repayment)

        What = (y1mat - y2mat)/2;   				% Full risk sharing transfers
		
        v1bar = sum(sum(prob.*util(c1mat,p1))); 		% per period autarky utility
        v2bar = sum(sum(prob.*util(c2mat,p2))); 		% per period autarky utility

        p1bar = 1-dyn*(1-sum(sum(prob.*(y1mat>=Db))));    	% prob of repayment in autarky
        p2bar = 1-dyn*(1-sum(sum(prob.*(y2mat>=Db))));    	% prob of repayment in autarky
        r1bar = (d*p1bar)/(1-d*p1bar);
        r2bar = (d*p2bar)/(1-d*p2bar);


        Wout = What;    					% Wout will hold the iterated maximum transfer

        % Start loop here
        crit = 1;
        iter = 0;

        while crit > critvalue;
            iter = iter + 1;
            Win = Wout;     

            y1t = y1mat - Win;  % 1's income after transfers
            p1t = 1-dyn*(1-sum(sum(prob.*(y1t>=Db))));    	% prob that 1 repays
            c1t = max(y1t-Db,0);                		% 1's consumption (subject to LL)
            r1t = (d*p1t)/(1-d*p1t);

            incr1 = util(c1mat,p1) - r1t * sum(sum(prob.*util(c1t,p1))) + r1bar * v1bar;
            W1max = c1mat - invU(incr1,p1);
            W1out = (Win-(W1max<Win)*step).*(y1mat~=y2mat);  

            y2t = y2mat + W1out;
            p2t = 1-dyn*(1-sum(sum(prob.*(y2t>=Db))));    	% prob that 2 repays
            c2t = max(y2t-Db,0);                 		% 2's consumption (subject to LL)
            r2t = (d*p2t)/(1-d*p2t);

            incr2 = util(c2mat,p2) - r2t * sum(sum(prob.*util(c2t,p2))) + r2bar * v2bar;
            W2max = c2mat - invU(incr2,p2);
            Wout = (W1out + (W2max<(-1*W1out))*step).*(y1mat~=y2mat); 

            crit = max(max(abs(Wout-Win)));
        end

        c1full = max(y1mat-What-Db,0);
        c2full = max(y2mat+What-Db,0);

        c1sust = max(y1mat-Wout-Db,0);
        c2sust = max(y2mat+Wout-Db,0);

        p1full = 1-dyn*(1-(sum(sum(prob.*((y1mat-What)>=Db)))));    
        p2full = 1-dyn*(1-(sum(sum(prob.*((y2mat+What)>=Db)))));    

        p1sust = 1-dyn*(1-(sum(sum(prob.*((y1mat-Wout)>=Db)))));    
        p2sust = 1-dyn*(1-(sum(sum(prob.*((y2mat+Wout)>=Db)))));    


        v1full = (1-d)/(1-d*p1full)*sum(sum(prob.*util(c1full,p1)));
        v2full = (1-d)/(1-d*p2full)*sum(sum(prob.*util(c2full,p2)));

        v1sust = (1-d)/(1-d*p1sust)*sum(sum(prob.*util(c1sust,p1)));
        v2sust = (1-d)/(1-d*p2sust)*sum(sum(prob.*util(c2sust,p2)));

        propgain1 = (v1sust-v1bar)/(v1full-v1bar);
        propgain2 = (v2sust-v2bar)/(v2full-v2bar);


        transmat=[0 y2;[y1' Wout]];

        disp('   ');
        disp('*******************************************');
        disp('Input Parameters');
        disp('*******************************************');
        disp(['rho1 (CRRA)            : ',num2str(p1)]); 
        disp(['rho2 (CRRA)            : ',num2str(p2)]);
        disp('   ');
        disp(['Discount Rate          : ',num2str(r)]);
        disp(['Implied Cont. Prob     : ',num2str(d)]);
        disp('   ');

        if dyn==1;
            disp('>>> With debt repayment dynamics');
        else
            disp('>>> NO debt repayment dynamics');
        end;

        disp('*******************************************');
        disp('Probability Matrix');
        disp('*******************************************');
        disp(['  y2  >',sprintf('%10.0f',y2)]);
        disp('           ------    ------    ------');
        for i = 1:length(y1)
            disp([sprintf('y1=%3.0f |',y1(i)) sprintf('%10.3f',[prob(i,:)])]);
        end

        disp('   ');
        disp('*******************************************');
        disp('Maximum Transfers');
        disp('*******************************************');
        disp(['  y2  >',sprintf('%10.0f',y2)]);
        disp('           ------    ------    ------');
        for i = 1:length(y1)
            disp([sprintf('y1=%3.0f |',y1(i)) sprintf('%10.3f',[Wout(i,:)])]);
        end
        disp('   ');

        disp('*******************************************');
        disp('Relative Utility');
        disp('*******************************************');
        disp('                   Agent 1     Agent 2');
        disp('                  ---------   ---------');
        disp(['Autarky    : ',sprintf('%12.3f',[(1-d)/(1-d*p1bar)*v1bar (1-d)/(1-d*p2bar)*v2bar])]);
        disp(['Full       : ',sprintf('%12.3f',[v1full v2full])]);
        disp(['Sustainable: ',sprintf('%12.3f',[v1sust v2sust])]);
        disp(['Prop. Gain : ',sprintf('%12.3f',[propgain1 propgain2])]);
    
         outTran(iC,iP)   = Wout(2,1);
         outAut(iC,iP)    = (1-d)/(1-d*p1bar)*v1bar;
         outSust(iC,iP)   = v1sust;
         outFull(iC,iP)   = v1full;
     end
end
 
if dyn==1;
    csvwrite('C:\Users\fischerg\Documents\Docs\Research\groupLiability\excel\outTran2.csv',outTran)
    csvwrite('C:\Users\fischerg\Documents\Docs\Research\groupLiability\excel\outAut2.csv',outAut)
    csvwrite('C:\Users\fischerg\Documents\Docs\Research\groupLiability\excel\outSust2.csv',outSust)
    csvwrite('C:\Users\fischerg\Documents\Docs\Research\groupLiability\excel\outFull2.csv',outFull)
end;
toc